@@ -15,10 +15,12 @@
 
 import webob.exc
 
+import glance_store as store
+
 from glance.common import exception
 import glance.openstack.common.log as logging
 import glance.registry.client.v1.api as registry
-import glance.store as store
+
 
 LOG = logging.getLogger(__name__)
 
@@ -38,12 +40,12 @@ class BaseController(object):
         try:
             return registry.get_image_metadata(context, image_id)
         except exception.NotFound:
-            msg = _("Image with identifier %s not found") % image_id
+            msg = "Image with identifier %s not found" % image_id
             LOG.debug(msg)
             raise webob.exc.HTTPNotFound(
                 msg, request=request, content_type='text/plain')
         except exception.Forbidden:
-            msg = _("Forbidden image access")
+            msg = "Forbidden image access"
             LOG.debug(msg)
             raise webob.exc.HTTPForbidden(msg,
                                           request=request,
@@ -56,7 +58,7 @@ class BaseController(object):
         """
         image = self.get_image_meta_or_404(request, image_id)
         if image['status'] != 'active':
-            msg = _("Image %s is not active") % image_id
+            msg = "Image %s is not active" % image_id
             LOG.debug(msg)
             raise webob.exc.HTTPNotFound(
                 msg, request=request, content_type='text/plain')
@@ -74,10 +76,11 @@ class BaseController(object):
                             write_tenants.append(member['member_id'])
                         else:
                             read_tenants.append(member['member_id'])
-                store.set_acls(req.context, location_uri, public=public,
+                store.set_acls(location_uri, public=public,
                                read_tenants=read_tenants,
-                               write_tenants=write_tenants)
-            except exception.UnknownScheme:
+                               write_tenants=write_tenants,
+                               context=req.context)
+            except store.UnknownScheme:
                 msg = _("Store for image_id not found: %s") % image_id
                 raise webob.exc.HTTPBadRequest(explanation=msg,
                                                request=req,
