@@ -56,6 +56,7 @@ _LW = gettextutils._LW
 SUPPORTED_PARAMS = glance.api.v1.SUPPORTED_PARAMS
 SUPPORTED_FILTERS = glance.api.v1.SUPPORTED_FILTERS
 ACTIVE_IMMUTABLE = glance.api.v1.ACTIVE_IMMUTABLE
+IMMUTABLE = glance.api.v1.IMMUTABLE
 
 CONF = cfg.CONF
 CONF.import_opt('disk_formats', 'glance.common.config', group='image_format')
@@ -895,6 +896,14 @@ class Controller(controller.BaseController):
                                         request=req,
                                         content_type="text/plain")
 
+        for key in IMMUTABLE:
+            if (image_meta.get(key) is not None and
+                    image_meta.get(key) != orig_image_meta.get(key)):
+                msg = _("Forbidden to modify '%s' of image.") % key
+                raise HTTPForbidden(explanation=msg,
+                                    request=req,
+                                    content_type="text/plain")
+
         # The default behaviour for a PUT /images/<IMAGE_ID> is to
         # override any properties that were previously set. This, however,
         # leads to a number of issues for the common use case where a caller
