@@ -15,7 +15,6 @@
 #    under the License.
 
 from oslo.config import cfg
-import six
 import webob.exc
 
 from glance.api import policy
@@ -73,11 +72,11 @@ class Controller(controller.BaseController):
         try:
             members = registry.get_image_members(req.context, image_id)
         except exception.NotFound:
-            msg = _("Image with identifier %s not found") % image_id
+            msg = "Image with identifier %s not found" % image_id
             LOG.debug(msg)
             raise webob.exc.HTTPNotFound(msg)
         except exception.Forbidden:
-            msg = _("Unauthorized image access")
+            msg = "Unauthorized image access"
             LOG.debug(msg)
             raise webob.exc.HTTPForbidden(msg)
         return dict(members=members)
@@ -95,10 +94,10 @@ class Controller(controller.BaseController):
             registry.delete_member(req.context, image_id, id)
             self._update_store_acls(req, image_id)
         except exception.NotFound as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPNotFound(explanation=e.msg)
 
         return webob.exc.HTTPNoContent()
@@ -151,13 +150,13 @@ class Controller(controller.BaseController):
             registry.add_member(req.context, image_id, id, can_share)
             self._update_store_acls(req, image_id)
         except exception.Invalid as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.NotFound as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPNotFound(explanation=e.msg)
 
         return webob.exc.HTTPNoContent()
@@ -186,13 +185,13 @@ class Controller(controller.BaseController):
             registry.replace_members(req.context, image_id, body)
             self._update_store_acls(req, image_id)
         except exception.Invalid as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.NotFound as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPNotFound(explanation=e.msg)
 
         return webob.exc.HTTPNoContent()
@@ -213,10 +212,10 @@ class Controller(controller.BaseController):
         try:
             members = registry.get_member_images(req.context, id)
         except exception.NotFound as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPNotFound(explanation=e.msg)
         except exception.Forbidden as e:
-            LOG.debug(six.text_type(e))
+            LOG.debug(utils.exception_to_str(e))
             raise webob.exc.HTTPForbidden(explanation=e.msg)
         return dict(shared_images=members)
 
