@@ -25,11 +25,11 @@ import eventlet
 import os
 import sys
 
-import six
+from glance.common import utils
 
 # Monkey patch socket, time, select, threads
 eventlet.patcher.monkey_patch(all=False, socket=True, time=True,
-                              select=True, thread=True)
+                              select=True, thread=True, os=True)
 
 # If ../glance/__init__.py exists, add ../ to Python search path, so that
 # it will override what happens to be installed in /usr/(local/)lib/python...
@@ -39,25 +39,45 @@ possible_topdir = os.path.normpath(os.path.join(os.path.abspath(sys.argv[0]),
 if os.path.exists(os.path.join(possible_topdir, 'glance', '__init__.py')):
     sys.path.insert(0, possible_topdir)
 
+import glance_store
+from oslo.config import cfg
+import osprofiler.notifier
+import osprofiler.web
+
 from glance.common import config
 from glance.common import exception
 from glance.common import wsgi
+from glance import notifier
 from glance.openstack.common import log
-import glance.store
+
+CONF = cfg.CONF
+CONF.import_group("profiler", "glance.common.wsgi")
 
 
 def fail(returncode, e):
-    sys.stderr.write("ERROR: %s\n" % six.text_type(e))
+    sys.stderr.write("ERROR: %s\n" % utils.exception_to_str(e))
     sys.exit(returncode)
 
 
 def main():
     try:
         config.parse_args()
+        wsgi.set_eventlet_hub()
         log.setup('glance')
 
-        glance.store.create_stores()
-        glance.store.verify_default_store()
+        glance_store.register_opts(config.CONF)
+        glance_store.create_stores(config.CONF)
+        glance_store.verify_default_store()
+
+        if cfg.CONF.profiler.enabled:
+            _notifier = osprofiler.notifier.create("Messaging",
+                                                   notifier.messaging, {},
+                                                   notifier.get_transport(),
+                                                   "glance", "api",
+                                                   cfg.CONF.bind_host)
+            osprofiler.notifier.set(_notifier)
+        else:
+            osprofiler.web.disable()
 
         server = wsgi.Server()
         server.start(config.load_paste_app('glance-api'), default_port=9292)
