@@ -72,10 +72,6 @@ class NotFound(GlanceException):
     message = _("An object with the specified identifier was not found.")
 
 
-class UnknownScheme(GlanceException):
-    message = _("Unknown scheme '%(scheme)s' found in URI")
-
-
 class BadStoreUri(GlanceException):
     message = _("The Store URI was malformed.")
 
@@ -89,19 +85,11 @@ class Conflict(GlanceException):
                 "operated on.")
 
 
-class StorageFull(GlanceException):
-    message = _("There is not enough disk space on the image storage media.")
-
-
 class StorageQuotaFull(GlanceException):
     message = _("The size of the data %(image_size)s will exceed the limit. "
                 "%(remaining)s bytes remaining.")
 
 
-class StorageWriteDenied(GlanceException):
-    message = _("Permission to write image storage media denied.")
-
-
 class AuthBadRequest(GlanceException):
     message = _("Connect error/bad request to Auth service at URL %(url)s.")
 
@@ -130,6 +118,31 @@ class ProtectedImageDelete(Forbidden):
     message = _("Image %(image_id)s is protected and cannot be deleted.")
 
 
+class ProtectedMetadefNamespaceDelete(Forbidden):
+    message = _("Metadata definition namespace %(namespace)s is protected"
+                " and cannot be deleted.")
+
+
+class ProtectedMetadefNamespacePropDelete(Forbidden):
+    message = _("Metadata definition property %(property_name)s is protected"
+                " and cannot be deleted.")
+
+
+class ProtectedMetadefObjectDelete(Forbidden):
+    message = _("Metadata definition object %(object_name)s is protected"
+                " and cannot be deleted.")
+
+
+class ProtectedMetadefResourceTypeAssociationDelete(Forbidden):
+    message = _("Metadata definition resource-type-association"
+                " %(resource_type)s is protected and cannot be deleted.")
+
+
+class ProtectedMetadefResourceTypeSystemDelete(Forbidden):
+    message = _("Metadata definition resource-type %(resource_type_name)s is"
+                " a seeded-system type and cannot be deleted.")
+
+
 class Invalid(GlanceException):
     message = _("Data supplied was not valid.")
 
@@ -142,6 +155,10 @@ class InvalidPropertyProtectionConfiguration(Invalid):
     message = _("Invalid configuration in property protection file.")
 
 
+class InvalidSwiftStoreConfiguration(Invalid):
+    message = _("Invalid configuration in glance-swift conf file.")
+
+
 class InvalidFilterRangeValue(Invalid):
     message = _("Unable to filter using the specified range.")
 
@@ -184,7 +201,7 @@ class LimitExceeded(GlanceException):
 
 
 class ServiceUnavailable(GlanceException):
-    message = _("The request returned 503 Service Unavilable. This "
+    message = _("The request returned 503 Service Unavailable. This "
                 "generally occurs on service overload or other transient "
                 "outage.")
 
@@ -212,33 +229,11 @@ class BadRegistryConnectionConfiguration(GlanceException):
                 "Reason: %(reason)s")
 
 
-class BadStoreConfiguration(GlanceException):
-    message = _("Store %(store_name)s could not be configured correctly. "
-                "Reason: %(reason)s")
-
-
 class BadDriverConfiguration(GlanceException):
     message = _("Driver %(driver_name)s could not be configured correctly. "
                 "Reason: %(reason)s")
 
 
-class StoreDeleteNotSupported(GlanceException):
-    message = _("Deleting images from this store is not supported.")
-
-
-class StoreGetNotSupported(GlanceException):
-    message = _("Getting images from this store is not supported.")
-
-
-class StoreAddNotSupported(GlanceException):
-    message = _("Adding images to this store is not supported.")
-
-
-class StoreAddDisabled(GlanceException):
-    message = _("Configuration for store failed. Adding images to this "
-                "store is disabled.")
-
-
 class MaxRedirectsExceeded(GlanceException):
     message = _("Maximum redirects (%(redirects)s) was exceeded.")
 
@@ -345,3 +340,74 @@ class InvalidParameterValue(Invalid):
 class InvalidImageStatusTransition(Invalid):
     message = _("Image status transition from %(cur_status)s to"
                 " %(new_status)s is not allowed")
+
+
+class MetadefDuplicateNamespace(Duplicate):
+    message = _("The metadata definition namespace=%(namespace_name)s"
+                " already exists.")
+
+
+class MetadefDuplicateObject(Duplicate):
+    message = _("A metadata definition object with name=%(object_name)s"
+                " already exists in namespace=%(namespace_name)s.")
+
+
+class MetadefDuplicateProperty(Duplicate):
+    message = _("A metadata definition property with name=%(property_name)s"
+                " already exists in namespace=%(namespace_name)s.")
+
+
+class MetadefDuplicateResourceType(Duplicate):
+    message = _("A metadata definition resource-type with"
+                " name=%(resource_type_name)s already exists.")
+
+
+class MetadefDuplicateResourceTypeAssociation(Duplicate):
+    message = _("The metadata definition resource-type association of"
+                " resource-type=%(resource_type_name)s to"
+                " namespace=%(namespace_name)s"
+                " already exists.")
+
+
+class MetadefForbidden(Forbidden):
+    message = _("You are not authorized to complete this action.")
+
+
+class MetadefIntegrityError(Forbidden):
+    message = _("The metadata definition %(record_type)s with"
+                " name=%(record_name)s not deleted."
+                " Other records still refer to it.")
+
+
+class MetadefNamespaceNotFound(NotFound):
+    message = _("Metadata definition namespace=%(namespace_name)s"
+                "was not found.")
+
+
+class MetadefObjectNotFound(NotFound):
+    message = _("The metadata definition object with"
+                " name=%(object_name)s was not found in"
+                " namespace=%(namespace_name)s.")
+
+
+class MetadefPropertyNotFound(NotFound):
+    message = _("The metadata definition property with"
+                " name=%(property_name)s was not found in"
+                " namespace=%(namespace_name)s.")
+
+
+class MetadefResourceTypeNotFound(NotFound):
+    message = _("The metadata definition resource-type with"
+                " name=%(resource_type_name)s, was not found.")
+
+
+class MetadefResourceTypeAssociationNotFound(NotFound):
+    message = _("The metadata definition resource-type association of"
+                " resource-type=%(resource_type_name)s to"
+                " namespace=%(namespace_name)s,"
+                " was not found.")
+
+
+class MetadefRecordNotFound(NotFound):
+    message = _("Metadata definition %(record_type)s record not found"
+                " for id %(id)s.")
