@@ -12,78 +12,39 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import configparser
+import ConfigParser
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 
 from glance.common import exception
-from glance.i18n import _, _LE
+from glance.openstack.common import log as logging
 
 swift_opts = [
     cfg.StrOpt('default_swift_reference',
                default="ref1",
-               help=_("""
-Reference to default Swift account/backing store parameters.
-
-Provide a string value representing a reference to the default set
-of parameters required for using swift account/backing store for
-image storage. The default reference value for this configuration
-option is 'ref1'. This configuration option dereferences the
-parameters and facilitates image storage in Swift storage backend
-every time a new image is added.
-
-Possible values:
-    * A valid string value
-
-Related options:
-    * None
-
-""")),
+               help=_('The reference to the default swift account/backing '
+                      'store parameters to use for adding new images.')),
     cfg.StrOpt('swift_store_auth_address',
-               deprecated_reason=("""
-The option auth_address in the Swift back-end configuration file is
-used instead.
-"""),
                help=_('The address where the Swift authentication service '
-                      'is listening.')),
+                      'is listening.(deprecated)')),
     cfg.StrOpt('swift_store_user', secret=True,
-               deprecated_reason=("""
-The option 'user' in the Swift back-end configuration file is set instead.
-"""),
                help=_('The user to authenticate against the Swift '
-                      'authentication service.')),
+                      'authentication service (deprecated)')),
     cfg.StrOpt('swift_store_key', secret=True,
-               deprecated_reason=("""
-The option 'key' in the Swift back-end configuration file is used
-to set the authentication key instead.
-"""),
                help=_('Auth key for the user authenticating against the '
-                      'Swift authentication service.')),
+                      'Swift authentication service. (deprecated)')),
     cfg.StrOpt('swift_store_config_file', secret=True,
-               help=_("""
-File containing the swift account(s) configurations.
-
-Include a string value representing the path to a configuration
-file that has references for each of the configured Swift
-account(s)/backing stores. By default, no file path is specified
-and customized Swift referencing is disabled. Configuring this option
-is highly recommended while using Swift storage backend for image
-storage as it helps avoid storage of credentials in the
-database.
-
-Possible values:
-    * None
-    * String value representing a valid configuration file path
-
-Related options:
-    * None
-
-""")),
+               help=_('The config file that has the swift account(s)'
+                      'configs.')),
 ]
 
-CONFIG = configparser.ConfigParser()
-
+# NOTE(bourke): The default dict_type is collections.OrderedDict in py27, but
+# we must set manually for compatibility with py26
+CONFIG = ConfigParser.SafeConfigParser(dict_type=OrderedDict)
 LOG = logging.getLogger(__name__)
 
 
@@ -106,8 +67,8 @@ class SwiftParams(object):
 
     def _form_default_params(self):
         default = {}
-        if (CONF.swift_store_user and CONF.swift_store_key
-           and CONF.swift_store_auth_address):
+        if CONF.swift_store_user and CONF.swift_store_key \
+                and CONF.swift_store_auth_address:
             default['user'] = CONF.swift_store_user
             default['key'] = CONF.swift_store_key
             default['auth_address'] = CONF.swift_store_auth_address
@@ -119,7 +80,7 @@ class SwiftParams(object):
             conf_file = CONF.find_file(CONF.swift_store_config_file)
             CONFIG.read(conf_file)
         except Exception as e:
-            msg = (_LE("swift config file %(conf_file)s:%(exc)s not found") %
+            msg = (_("swift config file %(conf_file)s:%(exc)s not found") %
                    {'conf_file': CONF.swift_store_config_file, 'exc': e})
             LOG.error(msg)
             raise exception.InvalidSwiftStoreConfiguration()
@@ -132,7 +93,7 @@ class SwiftParams(object):
                 reference['user'] = CONFIG.get(ref, 'user')
                 reference['key'] = CONFIG.get(ref, 'key')
                 account_params[ref] = reference
-            except (ValueError, SyntaxError, configparser.NoOptionError):
-                LOG.exception(_LE("Invalid format of swift store config "
-                                  "cfg"))
+            except (ValueError, SyntaxError, ConfigParser.NoOptionError) as e:
+                LOG.exception(_("Invalid format of swift store config"
+                                "cfg"))
         return account_params
