@@ -1,5 +1,6 @@
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
+# Copyright 2014 SoftLayer Technologies, Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -29,16 +30,22 @@ from eventlet.green import socket
 import functools
 import os
 import platform
+import re
 import subprocess
 import sys
 import uuid
 
+import netaddr
 from OpenSSL import crypto
 from oslo.config import cfg
 from webob import exc
 
+import six
+
 from glance.common import exception
+from glance.openstack.common import excutils
 import glance.openstack.common.log as logging
+from glance.openstack.common import network_utils
 from glance.openstack.common import strutils
 
 CONF = cfg.CONF
@@ -100,9 +107,9 @@ def cooperative_iter(iter):
             sleep(0)
             yield chunk
     except Exception as err:
-        msg = _("Error: cooperative_iter exception %s") % err
-        LOG.error(msg)
-        raise
+        with excutils.save_and_reraise_exception():
+            msg = _("Error: cooperative_iter exception %s") % err
+            LOG.error(msg)
 
 
 def cooperative_read(fd):
@@ -203,27 +210,12 @@ def image_meta_to_http_headers(image_meta):
                 for pk, pv in v.items():
                     if pv is not None:
                         headers["x-image-meta-property-%s"
-                                % pk.lower()] = unicode(pv)
+                                % pk.lower()] = six.text_type(pv)
             else:
-                headers["x-image-meta-%s" % k.lower()] = unicode(v)
+                headers["x-image-meta-%s" % k.lower()] = six.text_type(v)
     return headers
 
 
-def add_features_to_http_headers(features, headers):
-    """
-    Adds additional headers representing glance features to be enabled.
-
-    :param headers: Base set of headers
-    :param features: Map of enabled features
-    """
-    if features:
-        for k, v in features.items():
-            if k.lower() in FEATURE_BLACKLIST:
-                raise exception.UnsupportedHeaderFeature(feature=k)
-            if v is not None:
-                headers[k.lower()] = unicode(v)
-
-
 def get_image_meta_from_headers(response):
     """
     Processes HTTP headers from a supplied response that
@@ -278,6 +270,27 @@ def get_image_meta_from_headers(response):
     return result
 
 
+def create_mashup_dict(image_meta):
+    """
+    Returns a dictionary-like mashup of the image core properties
+    and the image custom properties from given image metadata.
+
+    :param image_meta: metadata of image with core and custom properties
+    """
+
+    def get_items():
+        for key, value in six.iteritems(image_meta):
+            if isinstance(value, dict):
+                for subkey, subvalue in six.iteritems(
+                        create_mashup_dict(value)):
+                    if subkey not in image_meta:
+                        yield subkey, subvalue
+            else:
+                yield key, value
+
+    return dict(get_items())
+
+
 def safe_mkdirs(path):
     try:
         os.makedirs(path)
@@ -429,7 +442,7 @@ def mutating(func):
     @functools.wraps(func)
     def wrapped(self, req, *args, **kwargs):
         if req.context.read_only:
-            msg = _("Read-only access")
+            msg = "Read-only access"
             LOG.debug(msg)
             raise exc.HTTPForbidden(msg, request=req,
                                     content_type="text/plain")
@@ -438,10 +451,10 @@ def mutating(func):
 
 
 def setup_remote_pydev_debug(host, port):
-    error_msg = ('Error setting up the debug environment.  Verify that the'
-                 ' option pydev_worker_debug_port is pointing to a valid '
-                 'hostname or IP on which a pydev server is listening on'
-                 ' the port indicated by pydev_worker_debug_port.')
+    error_msg = _('Error setting up the debug environment.  Verify that the'
+                  ' option pydev_worker_debug_host is pointing to a valid '
+                  'hostname or IP on which a pydev server is listening on'
+                  ' the port indicated by pydev_worker_debug_port.')
 
     try:
         try:
@@ -455,8 +468,8 @@ def setup_remote_pydev_debug(host, port):
                         stderrToServer=True)
         return True
     except Exception:
-        LOG.exception(error_msg)
-        raise
+        with excutils.save_and_reraise_exception():
+            LOG.exception(error_msg)
 
 
 class LazyPluggable(object):
@@ -498,12 +511,14 @@ def validate_key_cert(key_file, cert_file):
     try:
         error_key_name = "private key"
         error_filename = key_file
-        key_str = open(key_file, "r").read()
+        with open(key_file, 'r') as keyfile:
+            key_str = keyfile.read()
         key = crypto.load_privatekey(crypto.FILETYPE_PEM, key_str)
 
-        error_key_name = "certficate"
+        error_key_name = "certificate"
         error_filename = cert_file
-        cert_str = open(cert_file, "r").read()
+        with open(cert_file, 'r') as certfile:
+            cert_str = certfile.read()
         cert = crypto.load_certificate(crypto.FILETYPE_PEM, cert_str)
     except IOError as ioe:
         raise RuntimeError(_("There is a problem with your %(error_key_name)s "
@@ -558,3 +573,85 @@ def is_uuid_like(val):
         return str(uuid.UUID(val)) == val
     except (TypeError, ValueError, AttributeError):
         return False
+
+
+def is_valid_port(port):
+    """Verify that port represents a valid port number."""
+    return str(port).isdigit() and int(port) > 0 and int(port) <= 65535
+
+
+def is_valid_ipv4(address):
+    """Verify that address represents a valid IPv4 address."""
+    try:
+        return netaddr.valid_ipv4(address)
+    except Exception:
+        return False
+
+
+def is_valid_ipv6(address):
+    """Verify that address represents a valid IPv6 address."""
+    try:
+        return netaddr.valid_ipv6(address)
+    except Exception:
+        return False
+
+
+def is_valid_hostname(hostname):
+    """Verify whether a hostname (not an FQDN) is valid."""
+    return re.match('^[a-zA-Z0-9-]+$', hostname) is not None
+
+
+def is_valid_fqdn(fqdn):
+    """Verify whether a host is a valid FQDN."""
+    return re.match('^[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$', fqdn) is not None
+
+
+def parse_valid_host_port(host_port):
+    """
+    Given a "host:port" string, attempts to parse it as intelligently as
+    possible to determine if it is valid. This includes IPv6 [host]:port form,
+    IPv4 ip:port form, and hostname:port or fqdn:port form.
+
+    Invalid inputs will raise a ValueError, while valid inputs will return
+    a (host, port) tuple where the port will always be of type int.
+    """
+
+    try:
+        try:
+            host, port = network_utils.parse_host_port(host_port)
+        except Exception:
+            raise ValueError(_('Host and port "%s" is not valid.') % host_port)
+
+        if not is_valid_port(port):
+            raise ValueError(_('Port "%s" is not valid.') % port)
+
+        # First check for valid IPv6 and IPv4 addresses, then a generic
+        # hostname. Failing those, if the host includes a period, then this
+        # should pass a very generic FQDN check. The FQDN check for letters at
+        # the tail end will weed out any hilariously absurd IPv4 addresses.
+
+        if not (is_valid_ipv6(host) or is_valid_ipv4(host) or
+                is_valid_hostname(host) or is_valid_fqdn(host)):
+            raise ValueError(_('Host "%s" is not valid.') % host)
+
+    except Exception as ex:
+        raise ValueError(_('%s '
+                           'Please specify a host:port pair, where host is an '
+                           'IPv4 address, IPv6 address, hostname, or FQDN. If '
+                           'using an IPv6 address, enclose it in brackets '
+                           'separately from the port (i.e., '
+                           '"[fe80::a:b:c]:9876").') % ex)
+
+    return (host, int(port))
+
+
+def exception_to_str(exc):
+    try:
+        error = six.text_type(exc)
+    except UnicodeError:
+        try:
+            error = str(exc)
+        except UnicodeError:
+            error = ("Caught '%(exception)s' exception." %
+                     {"exception": exc.__class__.__name__})
+    return strutils.safe_encode(error, errors='ignore')
