@@ -89,6 +89,9 @@ eventlet_opts = [
                       'max_header_line may need to be increased when using '
                       'large tokens (typically those generated by the '
                       'Keystone v3 API with big service catalogs')),
+    cfg.BoolOpt('http_keepalive', default=True,
+                help=_('If False, closes the client socket connection '
+                       'explicitly.')),
 ]
 
 profiler_opts = [
@@ -340,7 +343,8 @@ class Server(object):
                                  self.application,
                                  log=logging.WritableLogger(self.logger),
                                  custom_pool=self.pool,
-                                 debug=False)
+                                 debug=False,
+                                 keepalive=CONF.http_keepalive)
         except socket.error as err:
             if err[0] != errno.EINVAL:
                 raise
@@ -351,7 +355,8 @@ class Server(object):
         self.logger.info(_("Starting single process server"))
         eventlet.wsgi.server(sock, application, custom_pool=self.pool,
                              log=logging.WritableLogger(self.logger),
-                             debug=False)
+                             debug=False,
+                             keepalive=CONF.http_keepalive)
 
 
 class Middleware(object):
