@@ -16,10 +16,10 @@ from datetime import datetime
 
 from wsme import types as wsme_types
 
-from glance.common import timeutils
+from glance.openstack.common import timeutils
 
 
-class WSMEModelTransformer(object):
+class WSMEModelTransformer():
 
     def to_dict(self):
         # Return the wsme_attributes names:values as a dict
@@ -41,7 +41,7 @@ class WSMEModelTransformer(object):
         for name in names:
             value = getattr(db_entity, name, None)
             if value is not None:
-                if isinstance(value, datetime):
+                if type(value) == datetime:
                     iso_datetime_value = timeutils.isotime(value)
                     values.update({name: iso_datetime_value})
                 else:
