@@ -13,8 +13,7 @@
 #    under the License.
 
 
-from oslo_db import exception as db_exc
-from oslo_log import log as logging
+from oslo.db import exception as db_exc
 from sqlalchemy import func
 import sqlalchemy.orm as sa_orm
 
@@ -22,22 +21,25 @@ from glance.common import exception as exc
 from glance.db.sqlalchemy.metadef_api import namespace as namespace_api
 from glance.db.sqlalchemy.metadef_api import utils as metadef_utils
 from glance.db.sqlalchemy import models_metadef as models
-from glance.i18n import _
+from glance import i18n
+import glance.openstack.common.log as os_logging
 
-LOG = logging.getLogger(__name__)
+LOG = os_logging.getLogger(__name__)
+_LW = i18n._LW
 
 
 def _get(context, property_id, session):
 
     try:
-        query = session.query(models.MetadefProperty).filter_by(id=property_id)
+        query = session.query(models.MetadefProperty)\
+            .filter_by(id=property_id)
         property_rec = query.one()
 
     except sa_orm.exc.NoResultFound:
-        msg = (_("Metadata definition property not found for id=%s")
-               % property_id)
-        LOG.warning(msg)
-        raise exc.MetadefPropertyNotFound(msg)
+        LOG.warn(_LW("Metadata definition property not found for id=%s",
+                     property_id))
+        raise exc.MetadefRecordNotFound(
+            record_type='property', id=property_id)
 
     return property_rec
 
@@ -47,14 +49,15 @@ def _get_by_name(context, namespace_name, name, session):
 
     namespace = namespace_api.get(context, namespace_name, session)
     try:
-        query = session.query(models.MetadefProperty).filter_by(
-            name=name, namespace_id=namespace['id'])
+        query = session.query(models.MetadefProperty)\
+            .filter_by(name=name, namespace_id=namespace['id'])
         property_rec = query.one()
 
     except sa_orm.exc.NoResultFound:
-        LOG.debug("The metadata definition property with name=%(name)s"
-                  " was not found in namespace=%(namespace_name)s.",
-                  {'name': name, 'namespace_name': namespace_name})
+        msg = ("The metadata definition property with name=%(name)s"
+               " was not found in namespace=%(namespace_name)s."
+               % {'name': name, 'namespace_name': namespace_name})
+        LOG.debug(msg)
         raise exc.MetadefPropertyNotFound(property_name=name,
                                           namespace_name=namespace_name)
 
@@ -65,18 +68,18 @@ def get(context, namespace_name, name, session):
     """get a property; raise if ns not found/visible or property not found"""
 
     property_rec = _get_by_name(context, namespace_name, name, session)
-    return property_rec.to_dict()
+    return property_rec.as_dict()
 
 
 def get_all(context, namespace_name, session):
     namespace = namespace_api.get(context, namespace_name, session)
-    query = session.query(models.MetadefProperty).filter_by(
-        namespace_id=namespace['id'])
+    query = session.query(models.MetadefProperty)\
+        .filter_by(namespace_id=namespace['id'])
     properties = query.all()
 
     properties_list = []
     for prop in properties:
-        properties_list.append(prop.to_dict())
+        properties_list.append(prop.as_dict())
     return properties_list
 
 
@@ -91,16 +94,17 @@ def create(context, namespace_name, values, session):
     try:
         property_rec.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("Can not create metadata definition property. A property"
-                  " with name=%(name)s already exists in"
-                  " namespace=%(namespace_name)s.",
-                  {'name': property_rec.name,
-                   'namespace_name': namespace_name})
+        msg = ("Can not create metadata definition property. A property"
+               " with name=%(name)s already exists in"
+               " namespace=%(namespace_name)s."
+               % {'name': property_rec.name,
+                  'namespace_name': namespace_name})
+        LOG.debug(msg)
         raise exc.MetadefDuplicateProperty(
             property_name=property_rec.name,
             namespace_name=namespace_name)
 
-    return property_rec.to_dict()
+    return property_rec.as_dict()
 
 
 def update(context, namespace_name, property_id, values, session):
@@ -114,11 +118,12 @@ def update(context, namespace_name, property_id, values, session):
         property_rec.update(values.copy())
         property_rec.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("Invalid update. It would result in a duplicate"
-                  " metadata definition property with the same name=%(name)s"
-                  " in namespace=%(namespace_name)s.",
-                  {'name': property_rec.name,
-                   'namespace_name': namespace_name})
+        msg = ("Invalid update. It would result in a duplicate"
+               " metadata definition property with the same name=%(name)s"
+               " in namespace=%(namespace_name)s."
+               % {'name': property_rec.name,
+                  'namespace_name': namespace_name})
+        LOG.debug(msg)
         emsg = (_("Invalid update. It would result in a duplicate"
                   " metadata definition property with the same name=%(name)s"
                   " in namespace=%(namespace_name)s.")
@@ -126,7 +131,7 @@ def update(context, namespace_name, property_id, values, session):
                    'namespace_name': namespace_name})
         raise exc.MetadefDuplicateProperty(emsg)
 
-    return property_rec.to_dict()
+    return property_rec.as_dict()
 
 
 def delete(context, namespace_name, property_name, session):
@@ -136,15 +141,15 @@ def delete(context, namespace_name, property_name, session):
         session.delete(property_rec)
         session.flush()
 
-    return property_rec.to_dict()
+    return property_rec.as_dict()
 
 
 def delete_namespace_content(context, namespace_id, session):
     """Use this def only if the ns for the id has been verified as visible"""
 
     count = 0
-    query = session.query(models.MetadefProperty).filter_by(
-        namespace_id=namespace_id)
+    query = session.query(models.MetadefProperty)\
+        .filter_by(namespace_id=namespace_id)
     count = query.delete(synchronize_session='fetch')
     return count
 
@@ -159,6 +164,6 @@ def count(context, namespace_name, session):
 
     namespace = namespace_api.get(context, namespace_name, session)
 
-    query = session.query(func.count(models.MetadefProperty.id)).filter_by(
-        namespace_id=namespace['id'])
+    query = session.query(func.count(models.MetadefProperty.id))\
+        .filter_by(namespace_id=namespace['id'])
     return query.scalar()
