@@ -13,30 +13,31 @@
 #    under the License.
 
 
-from oslo_db import exception as db_exc
-from oslo_log import log as logging
+from oslo.db import exception as db_exc
 import sqlalchemy.exc as sa_exc
 import sqlalchemy.orm as sa_orm
 
 from glance.common import exception as exc
 import glance.db.sqlalchemy.metadef_api.utils as metadef_utils
 from glance.db.sqlalchemy import models_metadef as models
+import glance.openstack.common.log as os_logging
 
-LOG = logging.getLogger(__name__)
+LOG = os_logging.getLogger(__name__)
 
 
 def get(context, name, session):
     """Get a resource type, raise if not found"""
 
     try:
-        query = session.query(models.MetadefResourceType).filter_by(name=name)
+        query = session.query(models.MetadefResourceType)\
+            .filter_by(name=name)
         resource_type = query.one()
     except sa_orm.exc.NoResultFound:
-        LOG.debug("No metadata definition resource-type found with name %s",
-                  name)
+        msg = "No metadata definition resource-type found with name %s" % name
+        LOG.debug(msg)
         raise exc.MetadefResourceTypeNotFound(resource_type_name=name)
 
-    return resource_type.to_dict()
+    return resource_type.as_dict()
 
 
 def get_all(context, session):
@@ -47,7 +48,7 @@ def get_all(context, session):
 
     resource_types_list = []
     for rt in resource_types:
-        resource_types_list.append(rt.to_dict())
+        resource_types_list.append(rt.as_dict())
 
     return resource_types_list
 
@@ -61,13 +62,14 @@ def create(context, values, session):
     try:
         resource_type.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("Can not create the metadata definition resource-type. "
-                  "A resource-type with name=%s already exists.",
-                  resource_type.name)
+        msg = ("Can not create the metadata definition resource-type."
+               " A resource-type with name=%s already exists."
+               % resource_type.name)
+        LOG.debug(msg)
         raise exc.MetadefDuplicateResourceType(
             resource_type_name=resource_type.name)
 
-    return resource_type.to_dict()
+    return resource_type.as_dict()
 
 
 def update(context, values, session):
@@ -79,7 +81,7 @@ def update(context, values, session):
     db_rec.update(values.copy())
     db_rec.save(session=session)
 
-    return db_rec.to_dict()
+    return db_rec.as_dict()
 
 
 def delete(context, name, session):
@@ -87,8 +89,9 @@ def delete(context, name, session):
 
     db_rec = get(context, name, session)
     if db_rec.protected is True:
-        LOG.debug("Delete forbidden. Metadata definition resource-type %s is a"
-                  " seeded-system type and can not be deleted.", name)
+        msg = ("Delete forbidden. Metadata definition resource-type %s is a"
+               " seeded-system type and can not be deleted.") % name
+        LOG.debug(msg)
         raise exc.ProtectedMetadefResourceTypeSystemDelete(
             resource_type_name=name)
 
@@ -97,11 +100,12 @@ def delete(context, name, session):
         session.flush()
     except db_exc.DBError as e:
         if isinstance(e.inner_exception, sa_exc.IntegrityError):
-            LOG.debug("Could not delete Metadata definition resource-type %s"
-                      ". It still has content", name)
+            msg = ("Could not delete Metadata definition resource-type %s"
+                   ". It still has content") % name
+            LOG.debug(msg)
             raise exc.MetadefIntegrityError(
                 record_type='resource-type', record_name=name)
         else:
-            raise
+            raise e
 
-    return db_rec.to_dict()
+    return db_rec.as_dict()
