@@ -13,17 +13,20 @@
 #    under the License.
 
 
-from oslo_db import exception as db_exc
-from oslo_log import log as logging
+from oslo.db import exception as db_exc
 import sqlalchemy.orm as sa_orm
 
 from glance.common import exception as exc
-from glance.db.sqlalchemy.metadef_api import namespace as namespace_api
-from glance.db.sqlalchemy.metadef_api import resource_type as resource_type_api
-from glance.db.sqlalchemy.metadef_api import utils as metadef_utils
+from glance.db.sqlalchemy.metadef_api\
+    import namespace as namespace_api
+from glance.db.sqlalchemy.metadef_api\
+    import resource_type as resource_type_api
+from glance.db.sqlalchemy.metadef_api\
+    import utils as metadef_utils
 from glance.db.sqlalchemy import models_metadef as models
+import glance.openstack.common.log as os_logging
 
-LOG = logging.getLogger(__name__)
+LOG = os_logging.getLogger(__name__)
 
 
 def _to_db_dict(namespace_id, resource_type_id, model_dict):
@@ -56,21 +59,23 @@ def _set_model_dict(resource_type_name, properties_target, prefix,
     return model_dict
 
 
-def _get(context, session, namespace_name, resource_type_name,
-         namespace_id, resource_type_id):
+def _get(context, namespace_name, resource_type_name,
+         namespace_id, resource_type_id, session):
     """Get a namespace resource_type association"""
 
     # visibility check assumed done in calling routine via namespace_get
     try:
-        query = session.query(models.MetadefNamespaceResourceType).filter_by(
-            namespace_id=namespace_id, resource_type_id=resource_type_id)
+        query = session.query(models.MetadefNamespaceResourceType).\
+            filter_by(namespace_id=namespace_id,
+                      resource_type_id=resource_type_id)
         db_rec = query.one()
     except sa_orm.exc.NoResultFound:
-        LOG.debug("The metadata definition resource-type association of"
-                  " resource_type=%(resource_type_name)s to"
-                  " namespace_name=%(namespace_name)s was not found.",
-                  {'resource_type_name': resource_type_name,
-                   'namespace_name': namespace_name})
+        msg = ("The metadata definition resource-type association of"
+               " resource_type=%(resource_type_name)s to"
+               " namespace_name=%(namespace_name)s was not found."
+               % {'resource_type_name': resource_type_name,
+                  'namespace_name': namespace_name})
+        LOG.debug(msg)
         raise exc.MetadefResourceTypeAssociationNotFound(
             resource_type_name=resource_type_name,
             namespace_name=namespace_name)
@@ -79,8 +84,7 @@ def _get(context, session, namespace_name, resource_type_name,
 
 
 def _create_association(
-    context, session, namespace_name, resource_type_name, values,
-):
+        context, namespace_name, resource_type_name, values, session):
     """Create an association, raise if it already exists."""
 
     namespace_resource_type_rec = models.MetadefNamespaceResourceType()
@@ -91,65 +95,61 @@ def _create_association(
     try:
         namespace_resource_type_rec.save(session=session)
     except db_exc.DBDuplicateEntry:
-        LOG.debug("The metadata definition resource-type association of"
-                  " resource_type=%(resource_type_name)s to"
-                  " namespace=%(namespace_name)s, already exists.",
-                  {'resource_type_name': resource_type_name,
-                   'namespace_name': namespace_name})
+        msg = ("The metadata definition resource-type association of"
+               " resource_type=%(resource_type_name)s to"
+               " namespace=%(namespace_name)s, already exists."
+               % {'resource_type_name': resource_type_name,
+                  'namespace_name': namespace_name})
+        LOG.debug(msg)
         raise exc.MetadefDuplicateResourceTypeAssociation(
             resource_type_name=resource_type_name,
             namespace_name=namespace_name)
 
-    return namespace_resource_type_rec.to_dict()
+    return namespace_resource_type_rec.as_dict()
 
 
-def _delete(context, session, namespace_name, resource_type_name,
-            namespace_id, resource_type_id):
+def _delete(context, namespace_name, resource_type_name,
+            namespace_id, resource_type_id, session):
     """Delete a resource type association or raise if not found."""
 
-    db_rec = _get(
-        context, session, namespace_name, resource_type_name,
-        namespace_id, resource_type_id)
+    db_rec = _get(context, namespace_name, resource_type_name,
+                  namespace_id, resource_type_id, session)
     session.delete(db_rec)
     session.flush()
 
-    return db_rec.to_dict()
+    return db_rec.as_dict()
 
 
-def get(context, session, namespace_name, resource_type_name):
+def get(context, namespace_name, resource_type_name, session):
     """Get a resource_type associations; raise if not found"""
     namespace = namespace_api.get(
-        context, session, namespace_name)
+        context, namespace_name, session)
 
     resource_type = resource_type_api.get(
-        context, session, resource_type_name)
+        context, resource_type_name, session)
 
-    found = _get(
-        context, session, namespace_name, resource_type_name,
-        namespace['id'], resource_type['id'])
+    found = _get(context, namespace_name, resource_type_name,
+                 namespace['id'], resource_type['id'], session)
 
     return _to_model_dict(resource_type_name, found)
 
 
-def get_all_by_namespace(context, session, namespace_name):
+def get_all_by_namespace(context, namespace_name, session):
     """List resource_type associations by namespace, raise if not found"""
 
     # namespace get raises an exception if not visible
     namespace = namespace_api.get(
-        context, session, namespace_name)
+        context, namespace_name, session)
 
     db_recs = (
         session.query(models.MetadefResourceType)
         .join(models.MetadefResourceType.associations)
         .filter_by(namespace_id=namespace['id'])
-        .with_entities(
-            models.MetadefResourceType.name,
-            models.MetadefNamespaceResourceType.properties_target,
-            models.MetadefNamespaceResourceType.prefix,
-            models.MetadefNamespaceResourceType.created_at,
-            models.MetadefNamespaceResourceType.updated_at,
-        )
-    )
+        .values(models.MetadefResourceType.name,
+                models.MetadefNamespaceResourceType.properties_target,
+                models.MetadefNamespaceResourceType.prefix,
+                models.MetadefNamespaceResourceType.created_at,
+                models.MetadefNamespaceResourceType.updated_at))
 
     model_dict_list = []
     for name, properties_target, prefix, created_at, updated_at in db_recs:
@@ -161,11 +161,11 @@ def get_all_by_namespace(context, session, namespace_name):
     return model_dict_list
 
 
-def create(context, session, namespace_name, values):
+def create(context, namespace_name, values, session):
     """Create an association, raise if already exists or ns not found."""
 
     namespace = namespace_api.get(
-        context, session, namespace_name)
+        context, namespace_name, session)
 
     # if the resource_type does not exist, create it
     resource_type_name = values['name']
@@ -173,47 +173,45 @@ def create(context, session, namespace_name, values):
         models.MetadefNamespaceResourceType, values)
     try:
         resource_type = resource_type_api.get(
-            context, session, resource_type_name)
+            context, resource_type_name, session)
     except exc.NotFound:
         resource_type = None
-        LOG.debug("Creating resource-type %s", resource_type_name)
+        LOG.debug("Creating resource-type %s" % resource_type_name)
 
     if resource_type is None:
-        resource_type_dict = {'name': resource_type_name, 'protected': False}
+        resource_type_dict = {'name': resource_type_name, 'protected': 0}
         resource_type = resource_type_api.create(
-            context, session, resource_type_dict)
+            context, resource_type_dict, session)
 
     # Create the association record, set the field values
     ns_resource_type_dict = _to_db_dict(
         namespace['id'], resource_type['id'], values)
-    new_rec = _create_association(
-        context, session, namespace_name, resource_type_name,
-        ns_resource_type_dict)
+    new_rec = _create_association(context, namespace_name, resource_type_name,
+                                  ns_resource_type_dict, session)
 
     return _to_model_dict(resource_type_name, new_rec)
 
 
-def delete(context, session, namespace_name, resource_type_name):
+def delete(context, namespace_name, resource_type_name, session):
     """Delete an association or raise if not found"""
 
     namespace = namespace_api.get(
-        context, session, namespace_name)
+        context, namespace_name, session)
 
     resource_type = resource_type_api.get(
-        context, session, resource_type_name)
+        context, resource_type_name, session)
 
-    deleted = _delete(
-        context, session, namespace_name, resource_type_name,
-        namespace['id'], resource_type['id'])
+    deleted = _delete(context, namespace_name, resource_type_name,
+                      namespace['id'], resource_type['id'], session)
 
     return _to_model_dict(resource_type_name, deleted)
 
 
-def delete_namespace_content(context, session, namespace_id):
+def delete_namespace_content(context, namespace_id, session):
     """Use this def only if the ns for the id has been verified as visible"""
 
     count = 0
-    query = session.query(models.MetadefNamespaceResourceType).filter_by(
-        namespace_id=namespace_id)
+    query = session.query(models.MetadefNamespaceResourceType)\
+        .filter_by(namespace_id=namespace_id)
     count = query.delete(synchronize_session='fetch')
     return count
