@@ -8,4 +8,4 @@ DROP INDEX ix_image_properties_image_id_name ON image_properties;
 ALTER TABLE image_properties
 CHANGE COLUMN name `key` VARCHAR(255) NOT NULL;
 
-CREATE UNIQUE INDEX ix_image_properties_image_id_key ON image_properties (image_id, key);
+CREATE UNIQUE INDEX ix_image_properties_image_id_key ON image_properties (image_id, `key`);
