@@ -19,26 +19,31 @@ import datetime
 import uuid
 
 from oslo.config import cfg
+import six
 
 from glance.common import exception
+from glance import i18n
+from glance.openstack.common import excutils
+from glance.openstack.common import importutils
 import glance.openstack.common.log as logging
 from glance.openstack.common import timeutils
 
-
-CONF = cfg.CONF
+_LE = i18n._LE
 LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
+CONF.import_opt('task_executor', 'glance.common.config', group='task')
 
 
 _delayed_delete_imported = False
 
 
 def _import_delayed_delete():
-    # glance.store (indirectly) imports glance.domain therefore we can't put
+    # glance_store (indirectly) imports glance.domain therefore we can't put
     # the CONF.import_opt outside - we have to do it in a convoluted/indirect
     # way!
     global _delayed_delete_imported
     if not _delayed_delete_imported:
-        CONF.import_opt('delayed_delete', 'glance.store')
+        CONF.import_opt('delayed_delete', 'glance_store')
         _delayed_delete_imported = True
 
 
@@ -238,7 +243,7 @@ class Image(object):
         else:
             self.status = 'deleted'
 
-    def get_data(self):
+    def get_data(self, *args, **kwargs):
         raise NotImplementedError()
 
     def set_data(self, data, size=None):
@@ -311,7 +316,8 @@ class Task(object):
     _supported_task_status = ('pending', 'processing', 'success', 'failure')
 
     def __init__(self, task_id, task_type, status, owner,
-                 expires_at, created_at, updated_at, task_time_to_live=48):
+                 expires_at, created_at, updated_at,
+                 task_input, result, message, task_time_to_live=48):
 
         if task_type not in self._supported_task_type:
             raise exception.InvalidTaskType(task_type)
@@ -329,38 +335,52 @@ class Task(object):
         self._time_to_live = datetime.timedelta(hours=task_time_to_live)
         self.created_at = created_at
         self.updated_at = updated_at
+        self.task_input = task_input
+        self.result = result
+        self.message = message
 
     @property
     def status(self):
         return self._status
 
-    def run(self, executor):
-        pass
+    @property
+    def message(self):
+        return self._message
+
+    @message.setter
+    def message(self, message):
+        if message:
+            self._message = six.text_type(message)
+        else:
+            self._message = six.text_type('')
 
     def _validate_task_status_transition(self, cur_status, new_status):
-            valid_transitions = {
-                'pending': ['processing', 'failure'],
-                'processing': ['success', 'failure'],
-                'success': [],
-                'failure': [],
-            }
+        valid_transitions = {
+            'pending': ['processing', 'failure'],
+            'processing': ['success', 'failure'],
+            'success': [],
+            'failure': [],
+        }
 
-            if new_status in valid_transitions[cur_status]:
-                return True
-            else:
-                return False
+        if new_status in valid_transitions[cur_status]:
+            return True
+        else:
+            return False
 
     def _set_task_status(self, new_status):
         if self._validate_task_status_transition(self.status, new_status):
             self._status = new_status
-            log_msg = (_("Task status changed from %(cur_status)s to "
-                         "%(new_status)s") % {'cur_status': self.status,
-                                              'new_status': new_status})
+            log_msg = (_("Task [%(task_id)s] status changing from "
+                         "%(cur_status)s to %(new_status)s") %
+                       {'task_id': self.task_id, 'cur_status': self.status,
+                        'new_status': new_status})
             LOG.info(log_msg)
+            self._status = new_status
         else:
-            log_msg = (_("Task status failed to change from %(cur_status)s "
-                         "to %(new_status)s") % {'cur_status': self.status,
-                                                 'new_status': new_status})
+            log_msg = (_("Task [%(task_id)s] status failed to change from "
+                         "%(cur_status)s to %(new_status)s") %
+                       {'task_id': self.task_id, 'cur_status': self.status,
+                        'new_status': new_status})
             LOG.error(log_msg)
             raise exception.InvalidTaskStatusTransition(
                 cur_status=self.status,
@@ -383,22 +403,31 @@ class Task(object):
         self._set_task_status(new_status)
         self.expires_at = timeutils.utcnow() + self._time_to_live
 
+    def run(self, executor):
+        executor.begin_processing(self.task_id)
 
-class TaskDetails(object):
 
-    def __init__(self, task_id, task_input, message, result):
-        if task_id is None:
-            raise exception.TaskException(_('task_id is required to create '
-                                            'a new TaskDetails object'))
+class TaskStub(object):
+
+    def __init__(self, task_id, task_type, status, owner,
+                 expires_at, created_at, updated_at):
         self.task_id = task_id
-        self.input = task_input
-        self.message = message
-        self.result = result
+        self._status = status
+        self.type = task_type
+        self.owner = owner
+        self.expires_at = expires_at
+        self.created_at = created_at
+        self.updated_at = updated_at
+
+    @property
+    def status(self):
+        return self._status
 
 
 class TaskFactory(object):
 
-    def new_task(self, task_type, owner, task_time_to_live=48):
+    def new_task(self, task_type, owner, task_time_to_live=48,
+                 task_input=None, **kwargs):
         task_id = str(uuid.uuid4())
         status = 'pending'
         # Note(nikhil): expires_at would be set on the task, only when it
@@ -414,8 +443,164 @@ class TaskFactory(object):
             expires_at,
             created_at,
             updated_at,
+            task_input,
+            kwargs.get('message'),
+            kwargs.get('result'),
             task_time_to_live
         )
 
-    def new_task_details(self, task_id, task_input, message=None, result=None):
-        return TaskDetails(task_id, task_input, message, result)
+
+class TaskExecutorFactory(object):
+
+    def __init__(self, task_repo, image_repo, image_factory):
+        self.task_repo = task_repo
+        self.image_repo = image_repo
+        self.image_factory = image_factory
+
+    def new_task_executor(self, context):
+        try:
+            executor_cls = ('glance.async.%s_executor.'
+                            'TaskExecutor' % CONF.task.task_executor)
+            LOG.debug("Loading %s executor" % CONF.task.task_executor)
+            executor = importutils.import_class(executor_cls)
+            return executor(context,
+                            self.task_repo,
+                            self.image_repo,
+                            self.image_factory)
+        except ImportError:
+            with excutils.save_and_reraise_exception():
+                LOG.exception(_LE("Failed to load the %s executor provided "
+                                  "in the config.") % CONF.task.task_executor)
+
+
+class MetadefNamespace(object):
+
+    def __init__(self, namespace_id, namespace, display_name, description,
+                 owner, visibility, protected, created_at, updated_at):
+        self.namespace_id = namespace_id
+        self.namespace = namespace
+        self.display_name = display_name
+        self.description = description
+        self.owner = owner
+        self.visibility = visibility or "private"
+        self.protected = protected or False
+        self.created_at = created_at
+        self.updated_at = updated_at
+
+    def delete(self):
+        if self.protected:
+            raise exception.ProtectedMetadefNamespaceDelete(
+                namespace=self.namespace)
+
+
+class MetadefNamespaceFactory(object):
+
+    def new_namespace(self, namespace, owner, **kwargs):
+        namespace_id = str(uuid.uuid4())
+        created_at = timeutils.utcnow()
+        updated_at = created_at
+        return MetadefNamespace(
+            namespace_id,
+            namespace,
+            kwargs.get('display_name'),
+            kwargs.get('description'),
+            owner,
+            kwargs.get('visibility'),
+            kwargs.get('protected'),
+            created_at,
+            updated_at
+        )
+
+
+class MetadefObject(object):
+
+    def __init__(self, namespace, object_id, name, created_at, updated_at,
+                 required, description, properties):
+        self.namespace = namespace
+        self.object_id = object_id
+        self.name = name
+        self.created_at = created_at
+        self.updated_at = updated_at
+        self.required = required
+        self.description = description
+        self.properties = properties
+
+    def delete(self):
+        if self.namespace.protected:
+            raise exception.ProtectedMetadefObjectDelete(object_name=self.name)
+
+
+class MetadefObjectFactory(object):
+
+    def new_object(self, namespace, name, **kwargs):
+        object_id = str(uuid.uuid4())
+        created_at = timeutils.utcnow()
+        updated_at = created_at
+        return MetadefObject(
+            namespace,
+            object_id,
+            name,
+            created_at,
+            updated_at,
+            kwargs.get('required'),
+            kwargs.get('description'),
+            kwargs.get('properties')
+        )
+
+
+class MetadefResourceType(object):
+
+    def __init__(self, namespace, name, prefix, properties_target,
+                 created_at, updated_at):
+        self.namespace = namespace
+        self.name = name
+        self.prefix = prefix
+        self.properties_target = properties_target
+        self.created_at = created_at
+        self.updated_at = updated_at
+
+    def delete(self):
+        if self.namespace.protected:
+            raise exception.ProtectedMetadefResourceTypeAssociationDelete(
+                resource_type=self.name)
+
+
+class MetadefResourceTypeFactory(object):
+
+    def new_resource_type(self, namespace, name, **kwargs):
+        created_at = timeutils.utcnow()
+        updated_at = created_at
+        return MetadefResourceType(
+            namespace,
+            name,
+            kwargs.get('prefix'),
+            kwargs.get('properties_target'),
+            created_at,
+            updated_at
+        )
+
+
+class MetadefProperty(object):
+
+    def __init__(self, namespace, property_id, name, schema):
+        self.namespace = namespace
+        self.property_id = property_id
+        self.name = name
+        self.schema = schema
+
+    def delete(self):
+        if self.namespace.protected:
+            raise exception.ProtectedMetadefNamespacePropDelete(
+                property_name=self.name)
+
+
+class MetadefPropertyFactory(object):
+
+    def new_namespace_property(self, namespace, name, schema, **kwargs):
+        property_id = str(uuid.uuid4())
+        return MetadefProperty(
+            namespace,
+            property_id,
+            name,
+            schema
+        )
