@@ -14,8 +14,6 @@
 
 import re
 
-from hacking import core
-
 """
 Guidelines for writing new hacking checks
 
@@ -34,19 +32,17 @@ Guidelines for writing new hacking checks
 
 asse_trueinst_re = re.compile(
     r"(.)*assertTrue\(isinstance\((\w|\.|\'|\"|\[|\])+, "
-    r"(\w|\.|\'|\"|\[|\])+\)\)")
+    "(\w|\.|\'|\"|\[|\])+\)\)")
 asse_equal_type_re = re.compile(
     r"(.)*assertEqual\(type\((\w|\.|\'|\"|\[|\])+\), "
-    r"(\w|\.|\'|\"|\[|\])+\)")
+    "(\w|\.|\'|\"|\[|\])+\)")
 asse_equal_end_with_none_re = re.compile(
     r"(.)*assertEqual\((\w|\.|\'|\"|\[|\])+, None\)")
 asse_equal_start_with_none_re = re.compile(
     r"(.)*assertEqual\(None, (\w|\.|\'|\"|\[|\])+\)")
 unicode_func_re = re.compile(r"(\s|\W|^)unicode\(")
-dict_constructor_with_list_copy_re = re.compile(r".*\bdict\((\[)?(\(|\[)")
 
 
-@core.flake8ext
 def assert_true_instance(logical_line):
     """Check for assertTrue(isinstance(a, b)) sentences
 
@@ -56,7 +52,6 @@ def assert_true_instance(logical_line):
         yield (0, "G316: assertTrue(isinstance(a, b)) sentences not allowed")
 
 
-@core.flake8ext
 def assert_equal_type(logical_line):
     """Check for assertEqual(type(A), B) sentences
 
@@ -66,7 +61,6 @@ def assert_equal_type(logical_line):
         yield (0, "G317: assertEqual(type(A), B) sentences not allowed")
 
 
-@core.flake8ext
 def assert_equal_none(logical_line):
     """Check for assertEqual(A, None) or assertEqual(None, A) sentences
 
@@ -79,7 +73,6 @@ def assert_equal_none(logical_line):
                "sentences not allowed")
 
 
-@core.flake8ext
 def no_translate_debug_logs(logical_line, filename):
     dirs = [
         "glance/api",
@@ -89,41 +82,28 @@ def no_translate_debug_logs(logical_line, filename):
         "glance/domain",
         "glance/image_cache",
         "glance/quota",
+        "glance/registry",
         "glance/store",
         "glance/tests",
     ]
 
     if max([name in filename for name in dirs]):
         if logical_line.startswith("LOG.debug(_("):
-            yield (0, "G319: Don't translate debug level logs")
+            yield(0, "G319: Don't translate debug level logs")
 
 
-@core.flake8ext
-def check_no_contextlib_nested(logical_line):
-    msg = ("G327: contextlib.nested is deprecated since Python 2.7. See "
-           "https://docs.python.org/2/library/contextlib.html#contextlib."
-           "nested for more information.")
-    if ("with contextlib.nested(" in logical_line or
-            "with nested(" in logical_line):
-        yield (0, msg)
+def no_direct_use_of_unicode_function(logical_line):
+    """Check for use of unicode() builtin
 
-
-@core.flake8ext
-def dict_constructor_with_list_copy(logical_line):
-    msg = ("G328: Must use a dict comprehension instead of a dict constructor "
-           "with a sequence of key-value pairs.")
-    if dict_constructor_with_list_copy_re.match(logical_line):
-        yield (0, msg)
-
-
-@core.flake8ext
-def no_log_warn(logical_line):
-    """Disallow 'LOG.warn('
-
-    Use LOG.warning() instead of Deprecated LOG.warn().
-    https://docs.python.org/3/library/logging.html#logging.warning
+    G320
     """
+    if unicode_func_re.match(logical_line):
+        yield(0, "G320: Use six.text_type() instead of unicode()")
 
-    msg = ("G330: LOG.warn is deprecated, please use LOG.warning!")
-    if "LOG.warn(" in logical_line:
-        yield (0, msg)
+
+def factory(register):
+    register(assert_true_instance)
+    register(assert_equal_type)
+    register(assert_equal_none)
+    register(no_translate_debug_logs)
+    register(no_direct_use_of_unicode_function)
