@@ -20,11 +20,14 @@ the Glance Registry API
 
 from glance.common.client import BaseClient
 from glance.common import crypt
+from glance.openstack.common import excutils
+from glance.openstack.common import gettextutils
 from glance.openstack.common import jsonutils
 import glance.openstack.common.log as logging
 from glance.registry.api.v1 import images
 
 LOG = logging.getLogger(__name__)
+_LI = gettextutils._LI
 
 
 class RegistryClient(BaseClient):
@@ -47,7 +50,7 @@ class RegistryClient(BaseClient):
                             **kwargs)
 
     def decrypt_metadata(self, image_metadata):
-        if self.metadata_encryption_key is not None:
+        if self.metadata_encryption_key:
             if image_metadata.get('location'):
                 location = crypt.urlsafe_decrypt(self.metadata_encryption_key,
                                                  image_metadata['location'])
@@ -57,12 +60,14 @@ class RegistryClient(BaseClient):
                 for loc in image_metadata['location_data']:
                     url = crypt.urlsafe_decrypt(self.metadata_encryption_key,
                                                 loc['url'])
-                    ld.append({'url': url, 'metadata': loc['metadata']})
+                    ld.append({'id': loc['id'], 'url': url,
+                               'metadata': loc['metadata'],
+                               'status': loc['status']})
                 image_metadata['location_data'] = ld
         return image_metadata
 
     def encrypt_metadata(self, image_metadata):
-        if self.metadata_encryption_key is not None:
+        if self.metadata_encryption_key:
             location_url = image_metadata.get('location')
             if location_url:
                 location = crypt.urlsafe_encrypt(self.metadata_encryption_key,
@@ -77,7 +82,10 @@ class RegistryClient(BaseClient):
                     else:
                         url = crypt.urlsafe_encrypt(
                             self.metadata_encryption_key, loc['url'], 64)
-                    ld.append({'url': url, 'metadata': loc['metadata']})
+                    ld.append({'url': url, 'metadata': loc['metadata'],
+                               'status': loc['status'],
+                               # NOTE(zhiyan): New location has no ID field.
+                               'id': loc.get('id')})
                 image_metadata['location_data'] = ld
         return image_metadata
 
@@ -89,7 +97,7 @@ class RegistryClient(BaseClient):
         :param marker: image id after which to start page
         :param limit: max number of images to return
         :param sort_key: results will be ordered by this image attribute
-        :param sort_dir: direction in which to to order results (asc, desc)
+        :param sort_dir: direction in which to order results (asc, desc)
         """
         params = self._extract_params(kwargs, images.SUPPORTED_PARAMS)
         res = self.do_request("GET", "/images", params=params)
@@ -107,19 +115,19 @@ class RegistryClient(BaseClient):
                                                          **kwargs)
             status = res.status
             request_id = res.getheader('x-openstack-request-id')
-            msg = (_("Registry request %(method)s %(action)s HTTP %(status)s"
-                     " request id %(request_id)s") %
+            msg = ("Registry request %(method)s %(action)s HTTP %(status)s"
+                   " request id %(request_id)s" %
                    {'method': method, 'action': action,
                     'status': status, 'request_id': request_id})
             LOG.debug(msg)
 
         except Exception as exc:
-            exc_name = exc.__class__.__name__
-            LOG.info(_("Registry client request %(method)s %(action)s "
-                       "raised %(exc_name)s"),
-                     {'method': method, 'action': action,
-                      'exc_name': exc_name})
-            raise
+            with excutils.save_and_reraise_exception():
+                exc_name = exc.__class__.__name__
+                LOG.info(_LI("Registry client request %(method)s %(action)s "
+                             "raised %(exc_name)s"),
+                         {'method': method, 'action': action,
+                          'exc_name': exc_name})
         return res
 
     def get_images_detailed(self, **kwargs):
@@ -130,7 +138,7 @@ class RegistryClient(BaseClient):
         :param marker: image id after which to start page
         :param limit: max number of images to return
         :param sort_key: results will be ordered by this image attribute
-        :param sort_dir: direction in which to to order results (asc, desc)
+        :param sort_dir: direction in which to order results (asc, desc)
         """
         params = self._extract_params(kwargs, images.SUPPORTED_PARAMS)
         res = self.do_request("GET", "/images/detail", params=params)
