@@ -31,7 +31,7 @@ from glance.tests import utils as test_utils
 # The default sort order of results is whatever sort key is specified,
 # plus created_at and id for ties.  When we're not specifying a sort_key,
 # we get the default (created_at). Some tests below expect the fixtures to be
-# returned in array-order, so if if the created_at timestamps are the same,
+# returned in array-order, so if the created_at timestamps are the same,
 # these tests rely on the UUID* values being in order
 UUID1, UUID2, UUID3 = sorted([str(uuid.uuid4()) for x in range(3)])
 
@@ -53,7 +53,8 @@ def build_image_fixture(**kwargs):
         'min_disk': 5,
         'min_ram': 256,
         'size': 19,
-        'locations': [{'url': "file:///tmp/glance-tests/2", 'metadata': {}}],
+        'locations': [{'url': "file:///tmp/glance-tests/2",
+                       'metadata': {}, 'status': 'active'}],
         'properties': {},
     }
     image.update(kwargs)
@@ -83,9 +84,9 @@ class TestDriver(test_utils.BaseTestCase):
         super(TestDriver, self).setUp()
         context_cls = context.RequestContext
         self.adm_context = context_cls(is_admin=True,
-                                       auth_tok='user:user:admin')
+                                       auth_token='user:user:admin')
         self.context = context_cls(is_admin=False,
-                                   auth_tok='user:user:user')
+                                   auth_token='user:user:user')
         self.db_api = db_tests.get_db(self.config)
         db_tests.reset_db(self.db_api)
         self.fixtures = self.build_image_fixtures()
@@ -144,13 +145,13 @@ class DriverTests(object):
         self.assertEqual(0, image['min_ram'])
         self.assertEqual(0, image['min_disk'])
         self.assertIsNone(image['owner'])
-        self.assertEqual(False, image['is_public'])
+        self.assertFalse(image['is_public'])
         self.assertIsNone(image['size'])
         self.assertIsNone(image['checksum'])
         self.assertIsNone(image['disk_format'])
         self.assertEqual([], image['locations'])
-        self.assertEqual(False, image['protected'])
-        self.assertEqual(False, image['deleted'])
+        self.assertFalse(image['protected'])
+        self.assertFalse(image['deleted'])
         self.assertIsNone(image['deleted_at'])
         self.assertEqual([], image['properties'])
         self.assertEqual(image['created_at'], create_time)
@@ -169,22 +170,26 @@ class DriverTests(object):
                           self.context, {'id': UUID1, 'status': 'queued'})
 
     def test_image_create_with_locations(self):
-        locations = [{'url': 'a', 'metadata': {}},
-                     {'url': 'b', 'metadata': {}}]
+        locations = [{'url': 'a', 'metadata': {}, 'status': 'active'},
+                     {'url': 'b', 'metadata': {}, 'status': 'active'}]
 
         fixture = {'status': 'queued',
                    'locations': locations}
         image = self.db_api.image_create(self.context, fixture)
-        actual = [{'url': l['url'], 'metadata': l['metadata']}
+        actual = [{'url': l['url'], 'metadata': l['metadata'],
+                   'status': l['status']}
                   for l in image['locations']]
         self.assertEqual(locations, actual)
 
     def test_image_create_with_location_data(self):
-        location_data = [{'url': 'a', 'metadata': {'key': 'value'}},
-                         {'url': 'b', 'metadata': {}}]
+        location_data = [{'url': 'a', 'metadata': {'key': 'value'},
+                          'status': 'active'},
+                         {'url': 'b', 'metadata': {},
+                          'status': 'active'}]
         fixture = {'status': 'queued', 'locations': location_data}
         image = self.db_api.image_create(self.context, fixture)
-        actual = [{'url': l['url'], 'metadata': l['metadata']}
+        actual = [{'url': l['url'], 'metadata': l['metadata'],
+                   'status': l['status']}
                   for l in image['locations']]
         self.assertEqual(location_data, actual)
 
@@ -196,7 +201,7 @@ class DriverTests(object):
                   for p in image['properties']]
         self.assertEqual(expected, actual)
 
-    def test_image_create_unknown_attribtues(self):
+    def test_image_create_unknown_attributes(self):
         fixture = {'ping': 'pong'}
         self.assertRaises(exception.Invalid,
                           self.db_api.image_create, self.context, fixture)
@@ -208,17 +213,28 @@ class DriverTests(object):
         self.assertNotEqual(image['created_at'], image['updated_at'])
 
     def test_image_update_with_locations(self):
-        locations = [{'url': 'a', 'metadata': {}},
-                     {'url': 'b', 'metadata': {}}]
+        locations = [{'url': 'a', 'metadata': {}, 'status': 'active'},
+                     {'url': 'b', 'metadata': {}, 'status': 'active'}]
         fixture = {'locations': locations}
         image = self.db_api.image_update(self.adm_context, UUID3, fixture)
+        self.assertEqual(2, len(image['locations']))
+        self.assertIn('id', image['locations'][0])
+        self.assertIn('id', image['locations'][1])
+        image['locations'][0].pop('id')
+        image['locations'][1].pop('id')
         self.assertEqual(locations, image['locations'])
 
     def test_image_update_with_location_data(self):
-        location_data = [{'url': 'a', 'metadata': {'key': 'value'}},
-                         {'url': 'b', 'metadata': {}}]
+        location_data = [{'url': 'a', 'metadata': {'key': 'value'},
+                          'status': 'active'},
+                         {'url': 'b', 'metadata': {}, 'status': 'active'}]
         fixture = {'locations': location_data}
         image = self.db_api.image_update(self.adm_context, UUID3, fixture)
+        self.assertEqual(2, len(image['locations']))
+        self.assertIn('id', image['locations'][0])
+        self.assertIn('id', image['locations'][1])
+        image['locations'][0].pop('id')
+        image['locations'][1].pop('id')
         self.assertEqual(location_data, image['locations'])
 
     def test_image_update(self):
@@ -248,13 +264,13 @@ class DriverTests(object):
         # New properties are set
         self.assertTrue('ping' in properties)
         self.assertEqual(properties['ping']['value'], 'pong')
-        self.assertEqual(properties['ping']['deleted'], False)
+        self.assertFalse(properties['ping']['deleted'])
 
         # Original properties still show up, but with deleted=True
         # TODO(markwash): db api should not return deleted properties
         self.assertTrue('foo' in properties)
         self.assertEqual(properties['foo']['value'], 'bar')
-        self.assertEqual(properties['foo']['deleted'], True)
+        self.assertTrue(properties['foo']['deleted'])
 
     def test_image_property_delete(self):
         fixture = {'name': 'ping', 'value': 'pong', 'image_id': UUID1}
@@ -289,9 +305,9 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         TENANT2 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         ctxt2 = context.RequestContext(is_admin=False, tenant=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2)
+                                       auth_token='user:%s:user' % TENANT2)
         image = self.db_api.image_create(
             ctxt1, {'status': 'queued', 'owner': TENANT1})
         self.assertRaises(exception.Forbidden,
@@ -443,7 +459,7 @@ class DriverTests(object):
         """
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         self.db_api.image_create(ctxt1, {'id': UUIDX,
                                          'status': 'queued',
@@ -465,7 +481,7 @@ class DriverTests(object):
         """
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         self.db_api.image_create(ctxt1, {'id': UUIDX,
                                          'status': 'queued',
@@ -487,7 +503,7 @@ class DriverTests(object):
         """
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         self.db_api.image_create(ctxt1, {'id': UUIDX,
                                          'status': 'queued',
@@ -509,7 +525,7 @@ class DriverTests(object):
         """
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         self.db_api.image_create(ctxt1, {'id': UUIDX,
                                          'status': 'queued',
@@ -531,7 +547,7 @@ class DriverTests(object):
         """
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         self.db_api.image_create(ctxt1, {'id': UUIDX,
                                          'status': 'queued',
@@ -553,7 +569,7 @@ class DriverTests(object):
         """
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         self.db_api.image_create(ctxt1, {'id': UUIDX,
                                          'status': 'queued',
@@ -583,7 +599,7 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False,
                                        tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         image_meta_data = {'id': UUIDX, 'status': 'queued', 'owner': TENANT1}
         self.db_api.image_create(ctxt1, image_meta_data)
@@ -591,7 +607,7 @@ class DriverTests(object):
         TENANT2 = str(uuid.uuid4())
         ctxt2 = context.RequestContext(is_admin=False,
                                        tenant=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2)
+                                       auth_token='user:%s:user' % TENANT2)
         UUIDY = str(uuid.uuid4())
         image_meta_data = {'id': UUIDY, 'status': 'queued', 'owner': TENANT2}
         self.db_api.image_create(ctxt2, image_meta_data)
@@ -606,7 +622,7 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False,
                                        tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
         UUIDX = str(uuid.uuid4())
         CHECKSUM1 = '91264c3edf5972c9f1cb309543d38a5c'
         image_meta_data = {
@@ -627,7 +643,7 @@ class DriverTests(object):
         TENANT2 = str(uuid.uuid4())
         ctxt2 = context.RequestContext(is_admin=False,
                                        tenant=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2)
+                                       auth_token='user:%s:user' % TENANT2)
         UUIDY = str(uuid.uuid4())
         CHECKSUM2 = '92264c3edf5972c9f1cb309543d38a5c'
         image_meta_data = {
@@ -733,9 +749,39 @@ class DriverTests(object):
         images = self.db_api.image_get_all(self.context, limit=2)
         self.assertEqual(2, len(images))
 
+    def test_image_get_all_with_tag_returning(self):
+        expected_tags = {UUID1: ['foo'], UUID2: ['bar'], UUID3: ['baz']}
+
+        self.db_api.image_tag_create(self.context, UUID1,
+                                     expected_tags[UUID1][0])
+        self.db_api.image_tag_create(self.context, UUID2,
+                                     expected_tags[UUID2][0])
+        self.db_api.image_tag_create(self.context, UUID3,
+                                     expected_tags[UUID3][0])
+
+        images = self.db_api.image_get_all(self.context, return_tag=True)
+        self.assertEqual(3, len(images))
+
+        for image in images:
+            self.assertIn('tags', image)
+            self.assertEqual(image['tags'], expected_tags[image['id']])
+
+        self.db_api.image_tag_delete(self.context, UUID1,
+                                     expected_tags[UUID1][0])
+        expected_tags[UUID1] = []
+
+        images = self.db_api.image_get_all(self.context, return_tag=True)
+        self.assertEqual(3, len(images))
+
+        for image in images:
+            self.assertIn('tags', image)
+            self.assertEqual(image['tags'], expected_tags[image['id']])
+
     def test_image_destroy(self):
-        location_data = [{'url': 'a', 'metadata': {'key': 'value'}},
-                         {'url': 'b', 'metadata': {}}]
+        location_data = [{'url': 'a', 'metadata': {'key': 'value'},
+                          'status': 'active'},
+                         {'url': 'b', 'metadata': {},
+                          'status': 'active'}]
         fixture = {'status': 'queued', 'locations': location_data}
         image = self.db_api.image_create(self.context, fixture)
         IMG_ID = image['id']
@@ -747,6 +793,11 @@ class DriverTests(object):
         member = self.db_api.image_member_create(self.context, fixture)
         self.db_api.image_tag_create(self.context, IMG_ID, 'snarf')
 
+        self.assertEqual(2, len(image['locations']))
+        self.assertIn('id', image['locations'][0])
+        self.assertIn('id', image['locations'][1])
+        image['locations'][0].pop('id')
+        image['locations'][1].pop('id')
         self.assertEqual(location_data, image['locations'])
         self.assertEqual(('ping', 'pong', IMG_ID, False),
                          (prop['name'], prop['value'],
@@ -767,7 +818,7 @@ class DriverTests(object):
         prop = image['properties'][0]
         self.assertEqual(('ping', IMG_ID, True),
                          (prop['name'], prop['image_id'], prop['deleted']))
-        self.context.auth_tok = 'user:%s:user' % TENANT2
+        self.context.auth_token = 'user:%s:user' % TENANT2
         members = self.db_api.image_member_find(self.context, IMG_ID)
         self.assertEqual([], members)
         tags = self.db_api.image_tag_get_all(self.context, IMG_ID)
@@ -780,8 +831,9 @@ class DriverTests(object):
         elements of the image to be deleted.
         """
         TENANT2 = str(uuid.uuid4())
-        location_data = [{'url': 'a', 'metadata': {'key': 'value'}},
-                         {'url': 'b', 'metadata': {}}]
+        location_data = [{'url': 'a', 'metadata': {'key': 'value'},
+                          'status': 'active'},
+                         {'url': 'b', 'metadata': {}, 'status': 'active'}]
 
         def _create_image_with_child_entries():
             fixture = {'status': 'queued', 'locations': location_data}
@@ -809,6 +861,11 @@ class DriverTests(object):
         self.assertFalse(active_image['deleted'])
         self.assertFalse(active_image['deleted_at'])
 
+        self.assertEqual(len(active_image['locations']), 2)
+        self.assertTrue('id' in active_image['locations'][0])
+        self.assertTrue('id' in active_image['locations'][1])
+        active_image['locations'][0].pop('id')
+        active_image['locations'][1].pop('id')
         self.assertEqual(location_data, active_image['locations'])
         self.assertEqual(1, len(active_image['properties']))
         prop = active_image['properties'][0]
@@ -817,7 +874,7 @@ class DriverTests(object):
                           prop['image_id']))
         self.assertEqual((False, None),
                          (prop['deleted'], prop['deleted_at']))
-        self.context.auth_tok = 'user:%s:user' % TENANT2
+        self.context.auth_token = 'user:%s:user' % TENANT2
         members = self.db_api.image_member_find(self.context, ACTIVE_IMG_ID)
         self.assertEqual(1, len(members))
         member = members[0]
@@ -831,10 +888,10 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         TENANT2 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         ctxt2 = context.RequestContext(is_admin=False, user=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2,
+                                       auth_token='user:%s:user' % TENANT2,
                                        owner_is_tenant=False)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
@@ -883,10 +940,10 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         TENANT2 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         ctxt2 = context.RequestContext(is_admin=False, user=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2,
+                                       auth_token='user:%s:user' % TENANT2,
                                        owner_is_tenant=False)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
@@ -961,7 +1018,7 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         # NOTE(flaper87): Update auth token, otherwise
         # non visible members won't be returned.
-        self.context.auth_tok = 'user:%s:user' % TENANT1
+        self.context.auth_token = 'user:%s:user' % TENANT1
         self.db_api.image_member_create(self.context,
                                         {'member': TENANT1, 'image_id': UUID1})
 
@@ -986,7 +1043,7 @@ class DriverTests(object):
 
         # NOTE(flaper87): Update auth token, otherwise
         # non visible members won't be returned.
-        self.context.auth_tok = 'user:%s:user' % TENANT1
+        self.context.auth_token = 'user:%s:user' % TENANT1
         member = self.db_api.image_member_create(self.context,
                                                  {'member': TENANT1,
                                                   'image_id': UUID1})
@@ -1027,7 +1084,7 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         # NOTE(flaper87): Update auth token, otherwise
         # non visible members won't be returned.
-        self.context.auth_tok = 'user:%s:user' % TENANT1
+        self.context.auth_token = 'user:%s:user' % TENANT1
         member = self.db_api.image_member_create(self.context,
                                                  {'member': TENANT1,
                                                   'image_id': UUID1})
@@ -1084,7 +1141,7 @@ class DriverTests(object):
 
         # NOTE(flaper87): Update auth token, otherwise
         # non visible members won't be returned.
-        self.context.auth_tok = 'user:%s:user' % TENANT1
+        self.context.auth_token = 'user:%s:user' % TENANT1
         output = self.db_api.image_member_find(self.context, member=TENANT1)
         _assertMemberListMatch([fixtures[0], fixtures[1]], output)
 
@@ -1094,7 +1151,7 @@ class DriverTests(object):
 
         # NOTE(flaper87): Update auth token, otherwise
         # non visible members won't be returned.
-        self.context.auth_tok = 'user:%s:user' % TENANT2
+        self.context.auth_token = 'user:%s:user' % TENANT2
         output = self.db_api.image_member_find(self.context,
                                                member=TENANT2,
                                                image_id=UUID1)
@@ -1106,7 +1163,7 @@ class DriverTests(object):
 
         # NOTE(flaper87): Update auth token, otherwise
         # non visible members won't be returned.
-        self.context.auth_tok = 'user:%s:user' % TENANT1
+        self.context.auth_token = 'user:%s:user' % TENANT1
         output = self.db_api.image_member_find(self.context,
                                                status='rejected')
         _assertMemberListMatch([fixtures[1]], output)
@@ -1158,7 +1215,7 @@ class DriverTests(object):
         TENANT1 = str(uuid.uuid4())
         # NOTE(flaper87): Update auth token, otherwise
         # non visible members won't be returned.
-        self.context.auth_tok = 'user:%s:user' % TENANT1
+        self.context.auth_token = 'user:%s:user' % TENANT1
         fixture = {'member': TENANT1, 'image_id': UUID1, 'can_share': True}
         member = self.db_api.image_member_create(self.context, fixture)
         self.assertEqual(1, len(self.db_api.image_member_find(self.context)))
@@ -1173,7 +1230,7 @@ class DriverQuotaTests(test_utils.BaseTestCase):
         self.owner_id1 = str(uuid.uuid4())
         self.context1 = context.RequestContext(
             is_admin=False, user=self.owner_id1, tenant=self.owner_id1,
-            auth_tok='%s:%s:user' % (self.owner_id1, self.owner_id1))
+            auth_token='%s:%s:user' % (self.owner_id1, self.owner_id1))
         self.db_api = db_tests.get_db(self.config)
         db_tests.reset_db(self.db_api)
         dt1 = timeutils.utcnow()
@@ -1230,7 +1287,8 @@ class DriverQuotaTests(test_utils.BaseTestCase):
                             'owner': self.owner_id1}
         new_fixture = build_image_fixture(**new_fixture_dict)
         new_fixture['locations'].append({'url': 'file:///some/path/file',
-                                         'metadata': {}})
+                                         'metadata': {},
+                                         'status': 'active'})
         self.db_api.image_create(self.context1, new_fixture)
 
         total = reduce(lambda x, y: x + y,
@@ -1250,7 +1308,8 @@ class DriverQuotaTests(test_utils.BaseTestCase):
                             'owner': self.owner_id1}
         new_fixture = build_image_fixture(**new_fixture_dict)
         new_fixture['locations'].append({'url': 'file:///some/path/file',
-                                         'metadata': {}})
+                                         'metadata': {},
+                                         'status': 'active'})
         self.db_api.image_create(self.context1, new_fixture)
 
         total = reduce(lambda x, y: x + y,
@@ -1267,11 +1326,11 @@ class TaskTests(test_utils.BaseTestCase):
 
     def setUp(self):
         super(TaskTests, self).setUp()
-        self.owner_id1 = str(uuid.uuid4())
+        self.owner_id = str(uuid.uuid4())
         self.adm_context = context.RequestContext(is_admin=True,
-                                                  auth_tok='user:user:admin')
+                                                  auth_token='user:user:admin')
         self.context = context.RequestContext(
-            is_admin=False, auth_tok='user:user:user', user=self.owner_id1)
+            is_admin=False, auth_token='user:user:user', user=self.owner_id)
         self.db_api = db_tests.get_db(self.config)
         self.fixtures = self.build_task_fixtures()
         db_tests.reset_db(self.db_api)
@@ -1314,10 +1373,10 @@ class TaskTests(test_utils.BaseTestCase):
 
     def test_task_get_all_with_filter(self):
         for fixture in self.fixtures:
-            self.db_api.task_create(self.context,
+            self.db_api.task_create(self.adm_context,
                                     build_task_fixture(**fixture))
 
-        import_tasks = self.db_api.task_get_all(self.context,
+        import_tasks = self.db_api.task_get_all(self.adm_context,
                                                 filters={'type': 'import'})
 
         self.assertTrue(import_tasks)
@@ -1329,7 +1388,7 @@ class TaskTests(test_utils.BaseTestCase):
     def test_task_get_all_as_admin(self):
         tasks = []
         for fixture in self.fixtures:
-            task = self.db_api.task_create(self.context,
+            task = self.db_api.task_create(self.adm_context,
                                            build_task_fixture(**fixture))
             tasks.append(task)
         import_tasks = self.db_api.task_get_all(self.adm_context)
@@ -1338,35 +1397,35 @@ class TaskTests(test_utils.BaseTestCase):
 
     def test_task_get_all_marker(self):
         for fixture in self.fixtures:
-            self.db_api.task_create(self.context,
+            self.db_api.task_create(self.adm_context,
                                     build_task_fixture(**fixture))
-        tasks = self.db_api.task_get_all(self.context, sort_key='id')
+        tasks = self.db_api.task_get_all(self.adm_context, sort_key='id')
         task_ids = [t['id'] for t in tasks]
-        tasks = self.db_api.task_get_all(self.context, sort_key='id',
+        tasks = self.db_api.task_get_all(self.adm_context, sort_key='id',
                                          marker=task_ids[0])
         self.assertEqual(len(tasks), 2)
 
     def test_task_get_all_limit(self):
         for fixture in self.fixtures:
-            self.db_api.task_create(self.context,
+            self.db_api.task_create(self.adm_context,
                                     build_task_fixture(**fixture))
 
-        tasks = self.db_api.task_get_all(self.context, limit=2)
+        tasks = self.db_api.task_get_all(self.adm_context, limit=2)
         self.assertEqual(2, len(tasks))
 
         # A limit of None should not equate to zero
-        tasks = self.db_api.task_get_all(self.context, limit=None)
+        tasks = self.db_api.task_get_all(self.adm_context, limit=None)
         self.assertEqual(3, len(tasks))
 
         # A limit of zero should actually mean zero
-        tasks = self.db_api.task_get_all(self.context, limit=0)
+        tasks = self.db_api.task_get_all(self.adm_context, limit=0)
         self.assertEqual(0, len(tasks))
 
     def test_task_get_all_owned(self):
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False,
                                        tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1)
+                                       auth_token='user:%s:user' % TENANT1)
 
         task_values = {'type': 'import', 'status': 'pending',
                        'input': '{"loc": "fake"}', 'owner': TENANT1}
@@ -1375,7 +1434,7 @@ class TaskTests(test_utils.BaseTestCase):
         TENANT2 = str(uuid.uuid4())
         ctxt2 = context.RequestContext(is_admin=False,
                                        tenant=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2)
+                                       auth_token='user:%s:user' % TENANT2)
 
         task_values = {'type': 'export', 'status': 'pending',
                        'input': '{"loc": "fake"}', 'owner': TENANT2}
@@ -1400,13 +1459,13 @@ class TaskTests(test_utils.BaseTestCase):
             'expires_at': expires_at
         }
 
-        task = self.db_api.task_create(self.context, fixture)
+        task = self.db_api.task_create(self.adm_context, fixture)
 
         self.assertIsNotNone(task)
         self.assertIsNotNone(task['id'])
 
         task_id = task['id']
-        task = self.db_api.task_get(self.context, task_id)
+        task = self.db_api.task_get(self.adm_context, task_id)
 
         self.assertIsNotNone(task)
         self.assertEqual(task['id'], task_id)
@@ -1445,8 +1504,8 @@ class TaskTests(test_utils.BaseTestCase):
             'updated_at': now
         }
 
-        task1 = self.db_api.task_create(self.context, fixture1)
-        task2 = self.db_api.task_create(self.context, fixture2)
+        task1 = self.db_api.task_create(self.adm_context, fixture1)
+        task2 = self.db_api.task_create(self.adm_context, fixture2)
 
         self.assertIsNotNone(task1)
         self.assertIsNotNone(task2)
@@ -1454,7 +1513,7 @@ class TaskTests(test_utils.BaseTestCase):
         task1_id = task1['id']
         task2_id = task2['id']
         task_fixtures = {task1_id: fixture1, task2_id: fixture2}
-        tasks = self.db_api.task_get_all(self.context)
+        tasks = self.db_api.task_get_all(self.adm_context)
 
         self.assertEqual(len(tasks), 2)
         self.assertEqual(set((tasks[0]['id'], tasks[1]['id'])),
@@ -1476,7 +1535,7 @@ class TaskTests(test_utils.BaseTestCase):
 
     def test_task_create(self):
         task_id = str(uuid.uuid4())
-        self.context.tenant = str(uuid.uuid4())
+        self.context.tenant = self.context.owner
         values = {
             'id': task_id,
             'owner': self.context.owner,
@@ -1484,7 +1543,7 @@ class TaskTests(test_utils.BaseTestCase):
             'status': 'pending',
         }
         task_values = build_task_fixture(**values)
-        task = self.db_api.task_create(self.context, task_values)
+        task = self.db_api.task_create(self.adm_context, task_values)
         self.assertIsNotNone(task)
         self.assertEqual(task['id'], task_id)
         self.assertEqual(task['owner'], self.context.owner)
@@ -1505,7 +1564,7 @@ class TaskTests(test_utils.BaseTestCase):
             'message': None,
         }
         task_values = build_task_fixture(**values)
-        task = self.db_api.task_create(self.context, task_values)
+        task = self.db_api.task_create(self.adm_context, task_values)
         self.assertIsNotNone(task)
         self.assertEqual(task['id'], task_id)
         self.assertEqual(task['owner'], self.context.owner)
@@ -1520,14 +1579,14 @@ class TaskTests(test_utils.BaseTestCase):
         result = {'foo': 'bar'}
         task_values = build_task_fixture(owner=self.context.owner,
                                          result=result)
-        task = self.db_api.task_create(self.context, task_values)
+        task = self.db_api.task_create(self.adm_context, task_values)
 
         task_id = task['id']
         fixture = {
             'status': 'processing',
             'message': 'This is a error string',
         }
-        task = self.db_api.task_update(self.context, task_id, fixture)
+        task = self.db_api.task_update(self.adm_context, task_id, fixture)
 
         self.assertEqual(task['id'], task_id)
         self.assertEqual(task['owner'], self.context.owner)
@@ -1536,7 +1595,7 @@ class TaskTests(test_utils.BaseTestCase):
         self.assertEqual(task['input'], {'ping': 'pong'})
         self.assertEqual(task['result'], result)
         self.assertEqual(task['message'], 'This is a error string')
-        self.assertEqual(task['deleted'], False)
+        self.assertFalse(task['deleted'])
         self.assertIsNone(task['deleted_at'])
         self.assertIsNone(task['expires_at'])
         self.assertEqual(task['created_at'], task_values['created_at'])
@@ -1548,11 +1607,11 @@ class TaskTests(test_utils.BaseTestCase):
                                          input=None,
                                          result=None,
                                          message=None)
-        task = self.db_api.task_create(self.context, task_values)
+        task = self.db_api.task_create(self.adm_context, task_values)
 
         task_id = task['id']
         fixture = {'status': 'processing'}
-        task = self.db_api.task_update(self.context, task_id, fixture)
+        task = self.db_api.task_update(self.adm_context, task_id, fixture)
 
         self.assertEqual(task['id'], task_id)
         self.assertEqual(task['owner'], self.context.owner)
@@ -1561,7 +1620,7 @@ class TaskTests(test_utils.BaseTestCase):
         self.assertIsNone(task['input'])
         self.assertIsNone(task['result'])
         self.assertIsNone(task['message'])
-        self.assertEqual(task['deleted'], False)
+        self.assertFalse(task['deleted'])
         self.assertIsNone(task['deleted_at'])
         self.assertIsNone(task['expires_at'])
         self.assertEqual(task['created_at'], task_values['created_at'])
@@ -1569,33 +1628,33 @@ class TaskTests(test_utils.BaseTestCase):
 
     def test_task_delete(self):
         task_values = build_task_fixture(owner=self.context.owner)
-        task = self.db_api.task_create(self.context, task_values)
+        task = self.db_api.task_create(self.adm_context, task_values)
 
         self.assertIsNotNone(task)
-        self.assertEqual(task['deleted'], False)
+        self.assertFalse(task['deleted'])
         self.assertIsNone(task['deleted_at'])
 
         task_id = task['id']
-        self.db_api.task_delete(self.context, task_id)
+        self.db_api.task_delete(self.adm_context, task_id)
         self.assertRaises(exception.TaskNotFound, self.db_api.task_get,
                           self.context, task_id)
 
     def test_task_delete_as_admin(self):
         task_values = build_task_fixture(owner=self.context.owner)
-        task = self.db_api.task_create(self.context, task_values)
+        task = self.db_api.task_create(self.adm_context, task_values)
 
         self.assertIsNotNone(task)
-        self.assertEqual(task['deleted'], False)
+        self.assertFalse(task['deleted'])
         self.assertIsNone(task['deleted_at'])
 
         task_id = task['id']
-        self.db_api.task_delete(self.context, task_id)
+        self.db_api.task_delete(self.adm_context, task_id)
         del_task = self.db_api.task_get(self.adm_context,
                                         task_id,
                                         force_show_deleted=True)
         self.assertIsNotNone(del_task)
         self.assertEqual(task_id, del_task['id'])
-        self.assertEqual(True, del_task['deleted'])
+        self.assertTrue(del_task['deleted'])
         self.assertIsNotNone(del_task['deleted_at'])
 
 
