@@ -14,15 +14,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo.config import cfg
+from oslo.db import options
+
 from glance.common import exception
 import glance.db.sqlalchemy.api
 from glance.db.sqlalchemy import models as db_models
+from glance.db.sqlalchemy import models_metadef as metadef_models
 import glance.tests.functional.db as db_tests
 from glance.tests.functional.db import base
+from glance.tests.functional.db import base_metadef
+
+CONF = cfg.CONF
 
 
 def get_db(config):
-    config(connection='sqlite://', group='database')
+    options.set_defaults(CONF, connection='sqlite://')
     config(verbose=False, debug=False)
     db_api = glance.db.sqlalchemy.api
     return db_api
@@ -33,6 +40,11 @@ def reset_db(db_api):
     db_models.register_models(db_api.get_engine())
 
 
+def reset_db_metadef(db_api):
+    metadef_models.unregister_models(db_api.get_engine())
+    metadef_models.register_models(db_api.get_engine())
+
+
 class TestSqlAlchemyDriver(base.TestDriver, base.DriverTests):
 
     def setUp(self):
@@ -131,3 +143,12 @@ class TestSqlAlchemyQuota(base.DriverQuotaTests):
         db_tests.load(get_db, reset_db)
         super(TestSqlAlchemyQuota, self).setUp()
         self.addCleanup(db_tests.reset)
+
+
+class TestMetadefSqlAlchemyDriver(base_metadef.TestMetadefDriver,
+                                  base_metadef.MetadefDriverTests):
+
+    def setUp(self):
+        db_tests.load(get_db, reset_db_metadef)
+        super(TestMetadefSqlAlchemyDriver, self).setUp()
+        self.addCleanup(db_tests.reset)
