@@ -14,9 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_utils import encodeutils
-
 from glance.common import exception
+from glance.common import utils
 import glance.context
 import glance.db
 import glance.tests.unit.utils as unit_test_utils
@@ -42,12 +41,6 @@ OBJECT1 = 'Object1'
 OBJECT2 = 'Object2'
 OBJECT3 = 'Object3'
 
-TAG1 = 'Tag1'
-TAG2 = 'Tag2'
-TAG3 = 'Tag3'
-TAG4 = 'Tag4'
-TAG5 = 'Tag5'
-
 RESOURCE_TYPE1 = 'ResourceType1'
 RESOURCE_TYPE2 = 'ResourceType2'
 RESOURCE_TYPE3 = 'ResourceType3'
@@ -86,26 +79,6 @@ def _db_object_fixture(name, **kwargs):
     return obj
 
 
-def _db_tag_fixture(name, **kwargs):
-    obj = {
-        'name': name
-    }
-    obj.update(kwargs)
-    return obj
-
-
-def _db_tags_fixture(names=None):
-    tags = []
-    if names:
-        tag_name_list = names
-    else:
-        tag_name_list = [TAG1, TAG2, TAG3]
-
-    for tag_name in tag_name_list:
-        tags.append(_db_tag_fixture(tag_name))
-    return tags
-
-
 def _db_resource_type_fixture(name, **kwargs):
     obj = {
         'name': name,
@@ -129,7 +102,8 @@ class TestMetadefRepo(test_utils.BaseTestCase):
 
     def setUp(self):
         super(TestMetadefRepo, self).setUp()
-        self.db = unit_test_utils.FakeDB(initialize=False)
+        self.db = unit_test_utils.FakeDB()
+        self.db.reset()
         self.context = glance.context.RequestContext(user=USER1,
                                                      tenant=TENANT1)
         self.namespace_repo = glance.db.MetadefNamespaceRepo(self.context,
@@ -138,22 +112,19 @@ class TestMetadefRepo(test_utils.BaseTestCase):
                                                            self.db)
         self.object_repo = glance.db.MetadefObjectRepo(self.context,
                                                        self.db)
-        self.tag_repo = glance.db.MetadefTagRepo(self.context,
-                                                 self.db)
-        self.resource_type_repo = glance.db.MetadefResourceTypeRepo(
-            self.context, self.db)
+        self.resource_type_repo = glance.db.\
+            MetadefResourceTypeRepo(self.context, self.db)
         self.namespace_factory = glance.domain.MetadefNamespaceFactory()
         self.property_factory = glance.domain.MetadefPropertyFactory()
         self.object_factory = glance.domain.MetadefObjectFactory()
-        self.tag_factory = glance.domain.MetadefTagFactory()
         self.resource_type_factory = glance.domain.MetadefResourceTypeFactory()
         self._create_namespaces()
         self._create_properties()
         self._create_objects()
-        self._create_tags()
         self._create_resource_types()
 
     def _create_namespaces(self):
+        self.db.reset()
         self.namespaces = [
             _db_namespace_fixture(namespace=NAMESPACE1,
                                   display_name='1',
@@ -208,17 +179,6 @@ class TestMetadefRepo(test_utils.BaseTestCase):
         [self.db.metadef_object_create(self.context, NAMESPACE4, object)
          for object in self.objects]
 
-    def _create_tags(self):
-        self.tags = [
-            _db_tag_fixture(name=TAG1),
-            _db_tag_fixture(name=TAG2),
-            _db_tag_fixture(name=TAG3),
-        ]
-        [self.db.metadef_tag_create(self.context, NAMESPACE1, tag)
-         for tag in self.tags]
-        [self.db.metadef_tag_create(self.context, NAMESPACE4, tag)
-         for tag in self.tags]
-
     def _create_resource_types(self):
         self.resource_types = [
             _db_resource_type_fixture(name=RESOURCE_TYPE1,
@@ -233,22 +193,22 @@ class TestMetadefRepo(test_utils.BaseTestCase):
 
     def test_get_namespace(self):
         namespace = self.namespace_repo.get(NAMESPACE1)
-        self.assertEqual(NAMESPACE1, namespace.namespace)
-        self.assertEqual('desc1', namespace.description)
-        self.assertEqual('1', namespace.display_name)
-        self.assertEqual(TENANT1, namespace.owner)
+        self.assertEqual(namespace.namespace, NAMESPACE1)
+        self.assertEqual(namespace.description, 'desc1')
+        self.assertEqual(namespace.display_name, '1')
+        self.assertEqual(namespace.owner, TENANT1)
         self.assertTrue(namespace.protected)
-        self.assertEqual('private', namespace.visibility)
+        self.assertEqual(namespace.visibility, 'private')
 
     def test_get_namespace_not_found(self):
         fake_namespace = "fake_namespace"
         exc = self.assertRaises(exception.NotFound,
                                 self.namespace_repo.get,
                                 fake_namespace)
-        self.assertIn(fake_namespace, encodeutils.exception_to_unicode(exc))
+        self.assertIn(fake_namespace, utils.exception_to_str(exc))
 
     def test_get_namespace_forbidden(self):
-        self.assertRaises(exception.MetadefForbidden,
+        self.assertRaises(exception.NotFound,
                           self.namespace_repo.get,
                           NAMESPACE3)
 
@@ -274,10 +234,10 @@ class TestMetadefRepo(test_utils.BaseTestCase):
                                           visibility='public',
                                           protected=True,
                                           owner=TENANT1)
-        self.assertEqual('added_namespace', namespace['namespace'])
+        self.assertEqual(namespace['namespace'], 'added_namespace')
         self.db.metadef_namespace_create(None, namespace)
         retrieved_namespace = self.namespace_repo.get(namespace['namespace'])
-        self.assertEqual('added_namespace', retrieved_namespace.namespace)
+        self.assertEqual(retrieved_namespace.namespace, 'added_namespace')
 
     def test_save_namespace(self):
         namespace = self.namespace_repo.get(NAMESPACE1)
@@ -285,8 +245,8 @@ class TestMetadefRepo(test_utils.BaseTestCase):
         namespace.description = 'save_desc'
         self.namespace_repo.save(namespace)
         namespace = self.namespace_repo.get(NAMESPACE1)
-        self.assertEqual('save_name', namespace.display_name)
-        self.assertEqual('save_desc', namespace.description)
+        self.assertEqual(namespace.display_name, 'save_name')
+        self.assertEqual(namespace.description, 'save_desc')
 
     def test_remove_namespace(self):
         namespace = self.namespace_repo.get(NAMESPACE1)
@@ -300,19 +260,19 @@ class TestMetadefRepo(test_utils.BaseTestCase):
         namespace.namespace = fake_name
         exc = self.assertRaises(exception.NotFound, self.namespace_repo.remove,
                                 namespace)
-        self.assertIn(fake_name, encodeutils.exception_to_unicode(exc))
+        self.assertIn(fake_name, utils.exception_to_str(exc))
 
     def test_get_property(self):
         property = self.property_repo.get(NAMESPACE1, PROPERTY1)
         namespace = self.namespace_repo.get(NAMESPACE1)
-        self.assertEqual(PROPERTY1, property.name)
-        self.assertEqual(namespace.namespace, property.namespace.namespace)
+        self.assertEqual(property.name, PROPERTY1)
+        self.assertEqual(property.namespace.namespace, namespace.namespace)
 
     def test_get_property_not_found(self):
         exc = self.assertRaises(exception.NotFound,
                                 self.property_repo.get,
                                 NAMESPACE2, PROPERTY1)
-        self.assertIn(PROPERTY1, encodeutils.exception_to_unicode(exc))
+        self.assertIn(PROPERTY1, utils.exception_to_str(exc))
 
     def test_list_property(self):
         properties = self.property_repo.list(filters={'namespace': NAMESPACE1})
@@ -329,25 +289,25 @@ class TestMetadefRepo(test_utils.BaseTestCase):
     def test_list_property_namespace_not_found(self):
         exc = self.assertRaises(exception.NotFound, self.property_repo.list,
                                 filters={'namespace': 'not-a-namespace'})
-        self.assertIn('not-a-namespace', encodeutils.exception_to_unicode(exc))
+        self.assertIn('not-a-namespace', utils.exception_to_str(exc))
 
     def test_add_property(self):
         # NOTE(pawel-koniszewski): Change db_property_fixture to
         # property_factory when property primary key in DB
         # will be changed from Integer to UUID
         property = _db_property_fixture(name='added_property')
-        self.assertEqual('added_property', property['name'])
+        self.assertEqual(property['name'], 'added_property')
         self.db.metadef_property_create(self.context, NAMESPACE1, property)
         retrieved_property = self.property_repo.get(NAMESPACE1,
                                                     'added_property')
-        self.assertEqual('added_property', retrieved_property.name)
+        self.assertEqual(retrieved_property.name, 'added_property')
 
     def test_add_property_namespace_forbidden(self):
         # NOTE(pawel-koniszewski): Change db_property_fixture to
         # property_factory when property primary key in DB
         # will be changed from Integer to UUID
         property = _db_property_fixture(name='added_property')
-        self.assertEqual('added_property', property['name'])
+        self.assertEqual(property['name'], 'added_property')
         self.assertRaises(exception.Forbidden, self.db.metadef_property_create,
                           self.context, NAMESPACE3, property)
 
@@ -356,7 +316,7 @@ class TestMetadefRepo(test_utils.BaseTestCase):
         # property_factory when property primary key in DB
         # will be changed from Integer to UUID
         property = _db_property_fixture(name='added_property')
-        self.assertEqual('added_property', property['name'])
+        self.assertEqual(property['name'], 'added_property')
         self.assertRaises(exception.NotFound, self.db.metadef_property_create,
                           self.context, 'not_a_namespace', property)
 
@@ -365,8 +325,8 @@ class TestMetadefRepo(test_utils.BaseTestCase):
         property.schema = '{"save": "schema"}'
         self.property_repo.save(property)
         property = self.property_repo.get(NAMESPACE1, PROPERTY1)
-        self.assertEqual(PROPERTY1, property.name)
-        self.assertEqual('{"save": "schema"}', property.schema)
+        self.assertEqual(property.name, PROPERTY1)
+        self.assertEqual(property.schema, '{"save": "schema"}')
 
     def test_remove_property(self):
         property = self.property_repo.get(NAMESPACE1, PROPERTY1)
@@ -384,16 +344,16 @@ class TestMetadefRepo(test_utils.BaseTestCase):
     def test_get_object(self):
         object = self.object_repo.get(NAMESPACE1, OBJECT1)
         namespace = self.namespace_repo.get(NAMESPACE1)
-        self.assertEqual(OBJECT1, object.name)
-        self.assertEqual('desc1', object.description)
-        self.assertEqual(['[]'], object.required)
-        self.assertEqual({}, object.properties)
-        self.assertEqual(namespace.namespace, object.namespace.namespace)
+        self.assertEqual(object.name, OBJECT1)
+        self.assertEqual(object.description, 'desc1')
+        self.assertEqual(object.required, ['[]'])
+        self.assertEqual(object.properties, {})
+        self.assertEqual(object.namespace.namespace, namespace.namespace)
 
     def test_get_object_not_found(self):
         exc = self.assertRaises(exception.NotFound, self.object_repo.get,
                                 NAMESPACE2, OBJECT1)
-        self.assertIn(OBJECT1, encodeutils.exception_to_unicode(exc))
+        self.assertIn(OBJECT1, utils.exception_to_str(exc))
 
     def test_list_object(self):
         objects = self.object_repo.list(filters={'namespace': NAMESPACE1})
@@ -408,25 +368,25 @@ class TestMetadefRepo(test_utils.BaseTestCase):
     def test_list_object_namespace_not_found(self):
         exc = self.assertRaises(exception.NotFound, self.object_repo.list,
                                 filters={'namespace': 'not-a-namespace'})
-        self.assertIn('not-a-namespace', encodeutils.exception_to_unicode(exc))
+        self.assertIn('not-a-namespace', utils.exception_to_str(exc))
 
     def test_add_object(self):
         # NOTE(pawel-koniszewski): Change db_object_fixture to
         # object_factory when object primary key in DB
         # will be changed from Integer to UUID
         object = _db_object_fixture(name='added_object')
-        self.assertEqual('added_object', object['name'])
+        self.assertEqual(object['name'], 'added_object')
         self.db.metadef_object_create(self.context, NAMESPACE1, object)
         retrieved_object = self.object_repo.get(NAMESPACE1,
                                                 'added_object')
-        self.assertEqual('added_object', retrieved_object.name)
+        self.assertEqual(retrieved_object.name, 'added_object')
 
     def test_add_object_namespace_forbidden(self):
         # NOTE(pawel-koniszewski): Change db_object_fixture to
         # object_factory when object primary key in DB
         # will be changed from Integer to UUID
         object = _db_object_fixture(name='added_object')
-        self.assertEqual('added_object', object['name'])
+        self.assertEqual(object['name'], 'added_object')
         self.assertRaises(exception.Forbidden, self.db.metadef_object_create,
                           self.context, NAMESPACE3, object)
 
@@ -435,7 +395,7 @@ class TestMetadefRepo(test_utils.BaseTestCase):
         # object_factory when object primary key in DB
         # will be changed from Integer to UUID
         object = _db_object_fixture(name='added_object')
-        self.assertEqual('added_object', object['name'])
+        self.assertEqual(object['name'], 'added_object')
         self.assertRaises(exception.NotFound, self.db.metadef_object_create,
                           self.context, 'not-a-namespace', object)
 
@@ -445,9 +405,9 @@ class TestMetadefRepo(test_utils.BaseTestCase):
         object.description = 'save_desc'
         self.object_repo.save(object)
         object = self.object_repo.get(NAMESPACE1, OBJECT1)
-        self.assertEqual(OBJECT1, object.name)
-        self.assertEqual(['save_req'], object.required)
-        self.assertEqual('save_desc', object.description)
+        self.assertEqual(object.name, OBJECT1)
+        self.assertEqual(object.required, ['save_req'])
+        self.assertEqual(object.description, 'save_desc')
 
     def test_remove_object(self):
         object = self.object_repo.get(NAMESPACE1, OBJECT1)
@@ -463,116 +423,6 @@ class TestMetadefRepo(test_utils.BaseTestCase):
                           object)
 
     def test_list_resource_type(self):
-        resource_type = self.resource_type_repo.list(
-            filters={'namespace': NAMESPACE1})
-        self.assertEqual(0, len(resource_type))
-
-    def test_get_tag(self):
-        tag = self.tag_repo.get(NAMESPACE1, TAG1)
-        namespace = self.namespace_repo.get(NAMESPACE1)
-        self.assertEqual(TAG1, tag.name)
-        self.assertEqual(namespace.namespace, tag.namespace.namespace)
-
-    def test_get_tag_not_found(self):
-        exc = self.assertRaises(exception.NotFound, self.tag_repo.get,
-                                NAMESPACE2, TAG1)
-        self.assertIn(TAG1, encodeutils.exception_to_unicode(exc))
-
-    def test_list_tag(self):
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE1})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([TAG1, TAG2, TAG3]), tag_names)
-
-    def test_list_tag_empty_result(self):
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE2})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([]), tag_names)
-
-    def test_list_tag_namespace_not_found(self):
-        exc = self.assertRaises(exception.NotFound, self.tag_repo.list,
-                                filters={'namespace': 'not-a-namespace'})
-        self.assertIn('not-a-namespace', encodeutils.exception_to_unicode(exc))
-
-    def test_add_tag(self):
-        # NOTE(pawel-koniszewski): Change db_tag_fixture to
-        # tag_factory when tag primary key in DB
-        # will be changed from Integer to UUID
-        tag = _db_tag_fixture(name='added_tag')
-        self.assertEqual('added_tag', tag['name'])
-        self.db.metadef_tag_create(self.context, NAMESPACE1, tag)
-        retrieved_tag = self.tag_repo.get(NAMESPACE1, 'added_tag')
-        self.assertEqual('added_tag', retrieved_tag.name)
-
-    def test_add_tags(self):
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE1})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([TAG1, TAG2, TAG3]), tag_names)
-
-        tags = _db_tags_fixture([TAG3, TAG4, TAG5])
-        self.db.metadef_tag_create_tags(self.context, NAMESPACE1, tags)
-
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE1})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([TAG3, TAG4, TAG5]), tag_names)
-
-    def test_add_tags_with_append_true(self):
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE1})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([TAG1, TAG2, TAG3]), tag_names)
-
-        tags = _db_tags_fixture([TAG4, TAG5])
-        self.db.metadef_tag_create_tags(self.context, NAMESPACE1, tags,
-                                        can_append=True)
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE1})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([TAG1, TAG2, TAG3, TAG4, TAG5]), tag_names)
-
-    def test_add_duplicate_tags_with_pre_existing_tags(self):
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE1})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([TAG1, TAG2, TAG3]), tag_names)
-
-        tags = _db_tags_fixture([TAG5, TAG4, TAG5])
-        self.assertRaises(exception.Duplicate,
-                          self.db.metadef_tag_create_tags,
-                          self.context, NAMESPACE1, tags)
-
-        tags = self.tag_repo.list(filters={'namespace': NAMESPACE1})
-        tag_names = set([t.name for t in tags])
-        self.assertEqual(set([TAG1, TAG2, TAG3]), tag_names)
-
-    def test_add_tag_namespace_forbidden(self):
-        # NOTE(pawel-koniszewski): Change db_tag_fixture to
-        # tag_factory when tag primary key in DB
-        # will be changed from Integer to UUID
-        tag = _db_tag_fixture(name='added_tag')
-        self.assertEqual('added_tag', tag['name'])
-        self.assertRaises(exception.Forbidden, self.db.metadef_tag_create,
-                          self.context, NAMESPACE3, tag)
-
-    def test_add_tag_namespace_not_found(self):
-        # NOTE(pawel-koniszewski): Change db_tag_fixture to
-        # tag_factory when tag primary key in DB
-        # will be changed from Integer to UUID
-        tag = _db_tag_fixture(name='added_tag')
-        self.assertEqual('added_tag', tag['name'])
-        self.assertRaises(exception.NotFound, self.db.metadef_tag_create,
-                          self.context, 'not-a-namespace', tag)
-
-    def test_save_tag(self):
-        tag = self.tag_repo.get(NAMESPACE1, TAG1)
-        self.tag_repo.save(tag)
-        tag = self.tag_repo.get(NAMESPACE1, TAG1)
-        self.assertEqual(TAG1, tag.name)
-
-    def test_remove_tag(self):
-        tag = self.tag_repo.get(NAMESPACE1, TAG1)
-        self.tag_repo.remove(tag)
-        self.assertRaises(exception.NotFound, self.tag_repo.get,
-                          NAMESPACE1, TAG1)
-
-    def test_remove_tag_not_found(self):
-        fake_name = 'fake_name'
-        tag = self.tag_repo.get(NAMESPACE1, TAG1)
-        tag.name = fake_name
-        self.assertRaises(exception.NotFound, self.tag_repo.remove, tag)
+        resource_type = self.resource_type_repo.list(filters=
+                                                     {'namespace': NAMESPACE1})
+        self.assertEqual(len(resource_type), 0)
