@@ -15,15 +15,16 @@
 
 import urllib
 
+import glance_store as store
 from oslo.config import cfg
 import six.moves.urllib.parse as urlparse
 
 from glance.common import exception
+from glance.common import store_utils
 from glance.common import wsgi
 import glance.context
 import glance.db.simple.api as simple_db
 import glance.openstack.common.log as logging
-import glance.store
 
 
 CONF = cfg.CONF
@@ -78,7 +79,7 @@ def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
     return req
 
 
-def fake_get_size_from_backend(context, uri):
+def fake_get_size_from_backend(uri, context=None):
     return 1
 
 
@@ -93,7 +94,7 @@ class FakeDB(object):
         images = [
             {'id': UUID1, 'owner': TENANT1, 'status': 'queued',
              'locations': [{'url': '%s/%s' % (BASE_URI, UUID1),
-                            'metadata': {}}]},
+                            'metadata': {}, 'status': 'queued'}]},
             {'id': UUID2, 'owner': TENANT1, 'status': 'queued'},
         ]
         [simple_db.image_create(None, image) for image in images]
@@ -114,6 +115,34 @@ class FakeDB(object):
         return getattr(simple_db, key)
 
 
+class FakeStoreUtils(object):
+    def __init__(self, store_api):
+        self.store_api = store_api
+
+    def safe_delete_from_backend(self, context, id, location):
+        try:
+            del self.store_api.data[location['url']]
+        except KeyError:
+            pass
+
+    def schedule_delayed_delete_from_backend(self, context, id, location):
+        pass
+
+    def delete_image_location_from_backend(self, context,
+                                           image_id, location):
+        if CONF.delayed_delete:
+            self.schedule_delayed_delete_from_backend(context, image_id,
+                                                      location)
+        else:
+            self.safe_delete_from_backend(context, image_id, location)
+
+    def validate_external_location(self, uri):
+        if uri and urlparse.urlparse(uri).scheme:
+            return store_utils.validate_external_location(uri)
+        else:
+            return True
+
+
 class FakeStoreAPI(object):
     def __init__(self, store_metadata=None):
         self.data = {
@@ -129,42 +158,34 @@ class FakeStoreAPI(object):
     def create_stores(self):
         pass
 
-    def set_acls(self, context, uri, public=False,
-                 read_tenants=[], write_tenants=[]):
+    def set_acls(self, uri, public=False, read_tenants=None,
+                 write_tenants=None, context=None):
+        if read_tenants is None:
+            read_tenants = []
+        if write_tenants is None:
+            write_tenants = []
+
         self.acls[uri] = {
             'public': public,
             'read': read_tenants,
             'write': write_tenants,
         }
 
-    def get_from_backend(self, context, location):
+    def get_from_backend(self, location, offset=0,
+                         chunk_size=None, context=None):
         try:
             scheme = location[:location.find('/') - 1]
             if scheme == 'unknown':
-                raise exception.UnknownScheme(scheme=scheme)
+                raise store.UnknownScheme(scheme=scheme)
             return self.data[location]
         except KeyError:
-            raise exception.NotFound()
+            raise store.NotFound()
 
-    def safe_delete_from_backend(self, context, uri, id, **kwargs):
-        try:
-            del self.data[uri]
-        except KeyError:
-            pass
+    def get_size_from_backend(self, location, context=None):
+        return self.get_from_backend(location, context=context)[1]
 
-    def schedule_delayed_delete_from_backend(self, context, uri, id, **kwargs):
-        pass
-
-    def delete_image_from_backend(self, context, store_api, image_id, uri):
-        if CONF.delayed_delete:
-            self.schedule_delayed_delete_from_backend(context, uri, image_id)
-        else:
-            self.safe_delete_from_backend(context, uri, image_id)
-
-    def get_size_from_backend(self, context, location):
-        return self.get_from_backend(context, location)[1]
-
-    def add_to_backend(self, context, scheme, image_id, data, size):
+    def add_to_backend(self, conf, image_id, data, size,
+                       scheme=None, context=None):
         store_max_size = 7
         current_store_size = 2
         for location in self.data.keys():
@@ -186,13 +207,7 @@ class FakeStoreAPI(object):
         return (image_id, size, checksum, self.store_metadata)
 
     def check_location_metadata(self, val, key=''):
-        glance.store.check_location_metadata(val)
-
-    def validate_external_location(self, uri):
-        if uri and urlparse.urlparse(uri).scheme:
-            return glance.store.validate_external_location(uri)
-        else:
-            return True
+        store.check_location_metadata(val)
 
 
 class FakePolicyEnforcer(object):
