@@ -21,6 +21,7 @@ import uuid
 import mock
 from oslo.config import cfg
 import routes
+import six
 import webob
 
 import glance.api.common
@@ -33,7 +34,6 @@ from glance.openstack.common import jsonutils
 from glance.openstack.common import timeutils
 
 from glance.registry.api import v1 as rserver
-import glance.store.filesystem
 from glance.tests.unit import base
 from glance.tests import utils as test_utils
 
@@ -58,7 +58,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
             return self.get_extra_fixture(
                 id, name,
                 locations=[{'url': "file:///%s/%s" % (self.test_dir, id),
-                            'metadata': {}}], **kwargs)
+                            'metadata': {}, 'status': 'active'}], **kwargs)
 
         self.FIXTURES = [
             _get_extra_fixture(UUID1, 'fake image #1', is_public=False,
@@ -92,7 +92,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         res = self.get_api_response_ext(200, '/images/%s' % UUID2)
         res_dict = jsonutils.loads(res.body)
         image = res_dict['image']
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, image[k])
 
     def test_show_unknown(self):
@@ -152,7 +152,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         images = res_dict['images']
         self.assertEqual(len(images), 1)
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, images[0][k])
 
     def test_get_index(self):
@@ -167,7 +167,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         images = res_dict['images']
         self.assertEqual(len(images), 1)
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, images[0][k])
 
     def test_get_index_marker(self):
@@ -210,7 +210,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         when a malformed marker is provided
         """
         res = self.get_api_response_ext(400, url='/images?marker=4')
-        self.assertTrue('marker' in res.body)
+        self.assertIn('marker', res.body)
 
     def test_get_index_forbidden_marker(self):
         """
@@ -670,7 +670,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         images = res_dict['images']
         self.assertEqual(len(images), 1)
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, images[0][k])
 
     def test_get_details_limit_marker(self):
@@ -713,7 +713,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         when a malformed marker is provided
         """
         res = self.get_api_response_ext(400, url='/images/detail?marker=4')
-        self.assertTrue('marker' in res.body)
+        self.assertIn('marker', res.body)
 
     def test_get_details_forbidden_marker(self):
         """
@@ -942,7 +942,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         self.assertEqual(len(images), 2)
 
         for image in images:
-            self.assertTrue(image['size'] <= 19 and image['size'] >= 18)
+            self.assertTrue(18 <= image['size'] <= 19)
 
     def test_get_details_filter_changes_since(self):
         """
@@ -1140,7 +1140,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         images = res_dict['images']
 
         for image in images:
-            self.assertEqual(False, image['deleted'])
+            self.assertFalse(image['deleted'])
 
     def test_get_filter_no_public_with_no_admin(self):
         """
@@ -1214,7 +1214,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
                                         method='POST', content_type='json')
         res_dict = jsonutils.loads(res.body)
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, res_dict['image'][k])
 
         # Test status was updated properly
@@ -1271,7 +1271,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
         res = self.get_api_response_ext(400, body=body,
                                         method='POST', content_type='json')
-        self.assertTrue('Invalid image status' in res.body)
+        self.assertIn('Invalid image status', res.body)
 
     def test_create_image_with_bad_id(self):
         """Tests proper exception is raised if a bad disk_format is set"""
@@ -1313,7 +1313,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         self.assertNotEqual(res_dict['image']['created_at'],
                             res_dict['image']['updated_at'])
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, res_dict['image'][k])
 
     @mock.patch.object(rserver.images.LOG, 'debug')
@@ -1344,7 +1344,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         self.assertNotEqual(res_dict['image']['created_at'],
                             res_dict['image']['updated_at'])
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, res_dict['image'][k])
 
     def test_update_image_not_existing(self):
@@ -1366,7 +1366,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         res = self.get_api_response_ext(400, method='PUT', body=body,
                                         url='/images/%s' % UUID2,
                                         content_type='json')
-        self.assertTrue('Invalid image status' in res.body)
+        self.assertIn('Invalid image status', res.body)
 
     def test_update_private_image_no_admin(self):
         """
@@ -1734,7 +1734,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         res = self.get_api_response_ext(404, method='DELETE',
                                         url=('/images/%s/members/pattieblack' %
                                              UUID2))
-        self.assertTrue('Membership could not be found' in res.body)
+        self.assertIn('Membership could not be found', res.body)
 
     def test_delete_member_from_non_exist_image(self):
         """
@@ -1767,6 +1767,19 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         res = req.get_response(api)
         self.assertEqual(res.status_int, 403)
 
+    def test_get_on_image_member(self):
+        """
+        Test GET on image members raises 405 and produces correct Allow headers
+        """
+        self.api = test_utils.FakeAuthMiddleware(rserver.API(self.mapper),
+                                                 is_admin=False)
+        uri = '/images/%s/members/123' % UUID1
+        req = webob.Request.blank(uri)
+        req.method = 'GET'
+        res = req.get_response(self.api)
+        self.assertEqual(405, res.status_int)
+        self.assertTrue(('Allow', 'PUT, DELETE') in res.headerlist)
+
     def test_get_images_bad_urls(self):
         """Check that routes collections are not on (LP bug 1185828)"""
         self.get_api_response_ext(404, url='/images/detail.xxx')
@@ -1794,7 +1807,7 @@ class TestRegistryAPILocations(base.IsolatedUnitTest,
             return self.get_extra_fixture(
                 id, name,
                 locations=[{'url': "file:///%s/%s" % (self.test_dir, id),
-                            'metadata': {}}], **kwargs)
+                            'metadata': {}, 'status': 'active'}], **kwargs)
 
         self.FIXTURES = [
             _get_extra_fixture(UUID1, 'fake image #1', is_public=False,
@@ -1820,6 +1833,8 @@ class TestRegistryAPILocations(base.IsolatedUnitTest,
         self.assertEqual(res.status_int, 200)
         res_dict = jsonutils.loads(res.body)
         image = res_dict['image']
+        self.assertIn('id', image['location_data'][0])
+        image['location_data'][0].pop('id')
         self.assertEqual(self.FIXTURES[0]['locations'][0],
                          image['location_data'][0])
         self.assertEqual(self.FIXTURES[0]['locations'][0]['url'],
@@ -1833,6 +1848,8 @@ class TestRegistryAPILocations(base.IsolatedUnitTest,
         self.assertEqual(res.status_int, 200)
         res_dict = jsonutils.loads(res.body)
         image = res_dict['image']
+        self.assertIn('id', image['location_data'][0])
+        image['location_data'][0].pop('id')
         self.assertEqual(self.FIXTURES[1]['locations'][0],
                          image['location_data'][0])
         self.assertEqual(self.FIXTURES[1]['locations'][0]['url'],
@@ -1859,9 +1876,11 @@ class TestRegistryAPILocations(base.IsolatedUnitTest,
                    'size': 19,
                    'location': encrypted_location_url1,
                    'location_data': [{'url': encrypted_location_url1,
-                                      'metadata': {'key': 'value'}},
+                                      'metadata': {'key': 'value'},
+                                      'status': 'active'},
                                      {'url': encrypted_location_url2,
-                                      'metadata': {'key': 'value'}}]}
+                                      'metadata': {'key': 'value'},
+                                      'status': 'active'}]}
 
         self.config(metadata_encryption_key=encryption_key)
         req = webob.Request.blank('/images')
@@ -1915,10 +1934,10 @@ class TestSharability(test_utils.BaseTestCase):
         TENANT1 = str(uuid.uuid4())
         TENANT2 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         ctxt2 = context.RequestContext(is_admin=True, user=TENANT2,
-                                       auth_tok='user:%s:admin' % TENANT2,
+                                       auth_token='user:%s:admin' % TENANT2,
                                        owner_is_tenant=False)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
@@ -1933,7 +1952,7 @@ class TestSharability(test_utils.BaseTestCase):
     def test_is_image_sharable_owner_can_share(self):
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
@@ -1949,10 +1968,10 @@ class TestSharability(test_utils.BaseTestCase):
         TENANT1 = str(uuid.uuid4())
         TENANT2 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         ctxt2 = context.RequestContext(is_admin=False, user=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2,
+                                       auth_token='user:%s:user' % TENANT2,
                                        owner_is_tenant=False)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
@@ -1968,10 +1987,10 @@ class TestSharability(test_utils.BaseTestCase):
         TENANT1 = str(uuid.uuid4())
         TENANT2 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         ctxt2 = context.RequestContext(is_admin=False, user=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2,
+                                       auth_token='user:%s:user' % TENANT2,
                                        owner_is_tenant=False)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
@@ -1993,10 +2012,10 @@ class TestSharability(test_utils.BaseTestCase):
         TENANT1 = str(uuid.uuid4())
         TENANT2 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         ctxt2 = context.RequestContext(is_admin=False, user=TENANT2,
-                                       auth_tok='user:%s:user' % TENANT2,
+                                       auth_token='user:%s:user' % TENANT2,
                                        owner_is_tenant=False)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
@@ -2017,10 +2036,10 @@ class TestSharability(test_utils.BaseTestCase):
     def test_is_image_sharable_owner_is_none(self):
         TENANT1 = str(uuid.uuid4())
         ctxt1 = context.RequestContext(is_admin=False, tenant=TENANT1,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         ctxt2 = context.RequestContext(is_admin=False, tenant=None,
-                                       auth_tok='user:%s:user' % TENANT1,
+                                       auth_token='user:%s:user' % TENANT1,
                                        owner_is_tenant=True)
         UUIDX = str(uuid.uuid4())
         #we need private image and context.owner should not match image owner
