@@ -15,6 +15,7 @@
 
 import datetime
 
+import glance_store
 from oslo.config import cfg
 import webob
 
@@ -101,7 +102,7 @@ class TestImageMembersController(test_utils.BaseTestCase):
                                                                self.policy,
                                                                self.notifier,
                                                                self.store)
-        glance.store.create_stores()
+        glance_store.create_stores()
 
     def _create_images(self):
         self.db.reset()
@@ -109,7 +110,7 @@ class TestImageMembersController(test_utils.BaseTestCase):
             _db_fixture(UUID1, owner=TENANT1, name='1', size=256,
                         is_public=True,
                         locations=[{'url': '%s/%s' % (BASE_URI, UUID1),
-                                    'metadata': {}}]),
+                                    'metadata': {}, 'status': 'active'}]),
             _db_fixture(UUID2, owner=TENANT1, name='2', size=512),
             _db_fixture(UUID3, owner=TENANT3, name='3', size=512),
             _db_fixture(UUID4, owner=TENANT4, name='4', size=1024),
@@ -308,6 +309,11 @@ class TestImageMembersController(test_utils.BaseTestCase):
         self.assertRaises(webob.exc.HTTPForbidden, self.controller.update,
                           request, UUID2, TENANT4, status='accepted')
 
+    def test_update_non_existent_image(self):
+        request = unit_test_utils.get_fake_request(tenant=TENANT1)
+        self.assertRaises(webob.exc.HTTPNotFound, self.controller.update,
+                          request, '123', TENANT4, status='accepted')
+
     def test_update_invalid_status(self):
         request = unit_test_utils.get_fake_request(tenant=TENANT4)
         self.assertRaises(webob.exc.HTTPBadRequest, self.controller.update,
