@@ -20,6 +20,7 @@ import uuid
 
 from oslo.config import cfg
 import routes
+import six
 import webob
 
 import glance.api.common
@@ -31,7 +32,6 @@ from glance.openstack.common import jsonutils
 from glance.openstack.common import timeutils
 
 from glance.registry.api import v2 as rserver
-import glance.store.filesystem
 from glance.tests.unit import base
 from glance.tests import utils as test_utils
 
@@ -70,7 +70,7 @@ class TestRegistryRPC(base.IsolatedUnitTest):
              'min_ram': 0,
              'size': 13,
              'locations': [{'url': "file:///%s/%s" % (self.test_dir, UUID1),
-                            'metadata': {}}],
+                            'metadata': {}, 'status': 'active'}],
              'properties': {'type': 'kernel'}},
             {'id': UUID2,
              'name': 'fake image #2',
@@ -87,7 +87,7 @@ class TestRegistryRPC(base.IsolatedUnitTest):
              'min_ram': 256,
              'size': 19,
              'locations': [{'url': "file:///%s/%s" % (self.test_dir, UUID2),
-                            'metadata': {}}],
+                            'metadata': {}, 'status': 'active'}],
              'properties': {}}]
 
         self.context = glance.context.RequestContext(is_admin=True)
@@ -135,7 +135,7 @@ class TestRegistryRPC(base.IsolatedUnitTest):
         self.assertEqual(res.status_int, 200)
         res_dict = jsonutils.loads(res.body)[0]
         image = res_dict
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, image[k])
 
     def test_show_unknown(self):
@@ -179,7 +179,7 @@ class TestRegistryRPC(base.IsolatedUnitTest):
         images = jsonutils.loads(res.body)[0]
         self.assertEqual(len(images), 1)
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, images[0][k])
 
     def test_get_index_marker(self):
@@ -1195,7 +1195,7 @@ class TestRegistryRPC(base.IsolatedUnitTest):
 
         res_dict = jsonutils.loads(res.body)[0]
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, res_dict[k])
 
         # Test status was updated properly
@@ -1319,7 +1319,7 @@ class TestRegistryRPC(base.IsolatedUnitTest):
         self.assertNotEqual(res_dict['created_at'],
                             res_dict['updated_at'])
 
-        for k, v in fixture.iteritems():
+        for k, v in six.iteritems(fixture):
             self.assertEqual(v, res_dict[k])
 
     def test_delete_image(self):
